(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1367827,      24616]*)
(*NotebookOutlinePosition[   1368832,      24648]*)
(*  CellTagsIndexPosition[   1368788,      24644]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Butterfly Mimicry", "Title"],

Cell[TextData[
"Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] August 1997 (copyright)"], 
  "Subsubtitle"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "For the last four billion years, nature has unfolded and still does show a \
great potential of creativity in developing mechanisms to adapt organisms to \
their specific environments. ",
  StyleBox["Mimesis",
    FontSlant->"Italic"],
  ", the imitation of colour and form of other objects, provides an excellent \
example for such adaptations. Some grasshoppers, like ",
  StyleBox["Cycloptera",
    FontSlant->"Italic"],
  ", look so much alike branchlets and leaves, that they are virtually \
invisible as prey. Thus there is no need for these grasshoppers to explicitly \
hide from their enemies."
}], "Text",
  TextJustification->0.75],

Cell["\<\
However, this kind of camouflage is not due to any intelligent \
behaviour of the grasshoppers, those special structure formations and surface \
colourings are the result of evolutionary selection processes over a large \
number of generations. Those grasshoppers more unlikely to be discovered \
simply have a higher chance of survial and are thus able to pass on their \
specific genes to their descendants.\
\>", "Text"],

Cell[TextData[{
  "Camouflage is observable with many other species, especially among \
butterflies, reptiles or fish. Many examples within the context of ",
  StyleBox["industrial",
    FontSlant->"Italic"],
  " ",
  StyleBox["melanism",
    FontSlant->"Italic"],
  " have been reported among butterfly populations, one favorite example \
being the ",
  StyleBox["peppered moth",
    FontSlant->"Italic"],
  " in Great Britain during the Industrial Revolution (",
  ButtonBox["Goldberg 1989",
    ButtonData:>{":::References.nb", "Goldberg 1989"},
    ButtonStyle->"Hyperlink"],
  ", p. 149f.). Its wildform had white wings with small black specks, an \
effective camouflage in the moth\.b4s natural habitat, lichen-covered trees. \
With growing air pollution near industrial towns, however, a shift in \
population balance from the white winged form to a melanic (dark) form could \
be observed. Nowadays, with improved filter systems that tremendously reduce \
air pollution the brighter coloured moth reappears."
}], "Text"],

Cell["\<\
We will examine simplified versions of these evolutionary \
adaptation effects in the following sections.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Butterfly camouflage evolved", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell[TextData[{
  "We simulate the evolution of butterfly wing colouring by the following \
simple model. A flock of butterflies located on a tree bark is represented by \
a vector W",
  Cell[BoxData[
      \(TraditionalForm\`\( = {w\_1\)\)]],
  ", \[Ellipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`w\_m\)]],
  "}, where each entry ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(w\_i\),
            "TraditionalForm"], "=", \((w\_i1\)}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\_i2\)]],
  ") either denotes a butterfly, ",
  Cell[BoxData[
      \(TraditionalForm\`w\_i\)]],
  "=(1, ",
  StyleBox["h",
    FontSlant->"Italic"],
  "), with ",
  StyleBox["h",
    FontSlant->"Italic"],
  " \[Element] [0,1] describing the hue of its wing colour, or a \
\[RightGuillemet]bark cell\[LeftGuillemet], ",
  Cell[BoxData[
      \(TraditionalForm\`w\_i\)]],
  "=(0, ",
  StyleBox["b",
    FontSlant->"Italic"],
  "), with ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Element] \([0, 1]\)\)]],
  " being the hue of the bark."
}], "Text"],

Cell[TextData[{
  "For each butterfly with wing hue ",
  StyleBox["h",
    FontSlant->"Italic"],
  " its capability of camouflaging within its environment is considered as \
its fitness, \[Tau](",
  StyleBox["h",
    FontSlant->"Italic"],
  "), which is computed as the inverse difference to the background colour \
value:"
}], "Text"],

Cell[TextData[{
  "\[Tau](",
  StyleBox["h",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\( | h - b | \)\)]]
}], "Text",
  TextAlignment->Center],

Cell["\<\
So the better a wing colour corresponds to the background colour, \
the more unlikely this butterfly is to be discovered by a bird.\
\>", "Text"],

Cell[TextData[{
  "The butterflies\.b4 struggle for survival will be modeled by the following \
two phases of selection and birth. Each of these phases is iterated for ",
  StyleBox["Round",
    FontSlant->"Italic"],
  "[",
  Cell[BoxData[
      \(TraditionalForm\`m\/\[Rho]\)]],
  "] many times, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Element] \([0, 1]\)\)]],
  " is the ",
  StyleBox["reduction-creation portion",
    FontSlant->"Italic"],
  ", the percentage of individuals to be replaced by mutant offspring."
}], "Text"],

Cell[CellGroupData[{

Cell["Selection", "Subsubsection"],

Cell[TextData[{
  "A butterfly will be selected with a probability proportionate to its \
inverse fitness ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\[Tau]\)]],
  ". The selected individual falls prey to a bird and leaves an empty cell of \
bark."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Birth", "Subsubsection"],

Cell[TextData[{
  "One of the remaining butterflies is selected at random; from this wildtype \
a mutant is generated which is placed at one of the empty bark spots. The \
mutation is influenced by the two parameters of mutation probability, \[Mu], \
and mutation radius, \[Rho]. For a more detailed explanation of these \
parameters see the example notebooks on ",
  ButtonBox["Cumulative Selection",
    ButtonData:>{"::Cumulative Selection:Cumulative Selection.nb", 
      "mutation"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Evolution experiments \[Ellipsis]"], "Subsection"],

Cell[TextData[{
  "For some further evolution experiments on butterfly camouflage see the ",
  ButtonBox["butterflies",
    ButtonData:>{"Butterflies-2D.nb", None},
    ButtonStyle->"Hyperlink"],
  " notebook."
}], "Text"],

Cell["\<\
Figure 1 illustrates a typical evolution experiment where an \
initially darker coloured population of butterflies eventually adopts to a \
bright background.\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 81 4 365 503
%%HiResBoundingBox: 81 4 365 503
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Dienstag, 9. September 1997) (14:32:53 Uhr)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 507 translate 1 -1 scale
1.000000 1.000000 1.000000 setrgbcolor
newpath
 81.000000 503.000000 moveto
 582.000000 503.000000 lineto
 582.000000 4.000000 lineto
 81.000000 4.000000 lineto
 81.000000 503.000000 lineto
closepath
fill
0.000000 0.000000 0.000000 setrgbcolor
1 setgray
81 227 moveto
138 227 lineto
138 4 lineto
81 4 lineto
closepath
fill
gsave
81 227 translate
57 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000CCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
000000CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737000000373737
000000000000373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737373737373737
373737373737373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737373737373737
373737373737373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737373737373737
373737373737373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCC000000
000000CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4000000000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737000000000000373737
000000000000373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000FFFFFF
000000000000000000FFFFFF000000000000CCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000FFFFFF000000
000000000000FFFFFF000000000000C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737000000000000FFFFFF000000000000
000000FFFFFF000000000000373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000004A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000
4A4A4A0000000000004A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000
7A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737000000373737
000000000000373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737373737373737
373737373737373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737373737373737
373737373737373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737373737373737373737
373737373737373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A000000000000
4A4A4A0000000000004A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A000000000000
7A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737373737373737000000000000373737
000000000000373737373737373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF
000000000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A000000000000FFFFFF000000
000000000000FFFFFF0000000000004A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF000000
000000000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000373737373737000000000000FFFFFF000000000000
000000FFFFFF000000000000373737373737000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
000000A5A5A5000000000000A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313000000
131313000000000000131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707000000070707
000000000000070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313131313
131313131313131313131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313131313
131313131313131313131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313131313
131313131313131313131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5000000
000000A5A5A5000000000000A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313000000000000
131313000000000000131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707000000000000070707
000000000000070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5000000000000FFFFFF
000000000000000000FFFFFF000000000000A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313000000000000FFFFFF000000
000000000000FFFFFF000000000000131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707000000000000FFFFFF000000000000
000000FFFFFF000000000000070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000009D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
000000C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000
9D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B0000003B3B3B
0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4000000
000000C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D000000000000
9D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B0000000000003B3B3B
0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000FFFFFF
000000000000000000FFFFFF000000000000C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000FFFFFF000000
000000000000FFFFFF0000000000009D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF000000000000
000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000919191000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191000000
919191000000000000919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000BDBDBD
000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191919191
919191919191919191919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191919191
919191919191919191919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191919191
919191919191919191919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191000000000000
919191000000000000919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000BDBDBD
000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF
000000000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191000000000000FFFFFF000000
000000000000FFFFFF000000000000919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000000000
000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
000000272727000000000000272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
272727272727272727272727272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
272727272727272727272727272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
272727272727272727272727272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727000000
000000272727000000000000272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272000000000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727000000000000FFFFFF
000000000000000000FFFFFF000000000000272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000FFFFFF000000
000000000000FFFFFF000000000000727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000002B2B2B2B2B2B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000002B2B2B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000002B2B2B2B2B2B2B2B2B2B2B2B2B2B2B000000
2B2B2B0000000000002B2B2B2B2B2B2B2B2B2B2B2B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000002B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000002B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000002B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000002B2B2B2B2B2B2B2B2B2B2B2B000000000000
2B2B2B0000000000002B2B2B2B2B2B2B2B2B2B2B2B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000002B2B2B2B2B2B000000000000FFFFFF000000
000000000000FFFFFF0000000000002B2B2B2B2B2B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF000000
000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676000000
767676000000000000767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676000000000000
767676000000000000767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737000000000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676000000000000FFFFFF000000
000000000000FFFFFF000000000000767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000FFFFFF000000
000000000000FFFFFF000000000000373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000000000
000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C0C0C0C0C0C0000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000C0C0C0000000FFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000000B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000004E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0
000000C0C0C0000000000000C0C0C0C0C0C0C0C0C0C0C0C0000000FFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000
0B0B0B0000000000000B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000
4E4E4E0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0
C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0000000FFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0
C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0000000FFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0
C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0000000FFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C0C0C0C0C0C0C0C0C0C0C0C0000000
000000C0C0C0000000000000C0C0C0C0C0C0C0C0C0C0C0C0000000FFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B000000000000
0B0B0B0000000000000B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E000000000000
4E4E4E0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C0C0C0C0C0C0000000000000FFFFFF
000000000000000000FFFFFF000000000000C0C0C0C0C0C0000000FFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B000000000000FFFFFF000000
000000000000FFFFFF0000000000000B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E000000000000FFFFFF000000
000000000000FFFFFF0000000000004E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000000000
000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000009D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000555555555555000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000555555000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
0000003B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000
9D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000
6A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000555555555555555555555555555555000000555555
000000000000555555555555555555555555000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000555555555555555555555555555555555555555555
555555555555555555555555555555555555000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000555555555555555555555555555555555555555555
555555555555555555555555555555555555000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000555555555555555555555555555555555555555555
555555555555555555555555555555555555000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000
0000003B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D000000000000
9D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A000000000000
6A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000555555555555555555555555000000000000555555
000000000000555555555555555555555555000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF
000000000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000FFFFFF000000
000000000000FFFFFF0000000000009D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000FFFFFF000000
000000000000FFFFFF0000000000006A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000555555555555000000000000FFFFFF000000000000
000000FFFFFF000000000000555555555555000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ADADADADADAD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ADADAD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000030303030303000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000030303000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ADADADADADADADADADADADADADADAD000000
ADADAD000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000030303030303030303030303030303000000030303
000000000000030303030303030303030303000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000030303030303030303030303030303030303030303
030303030303030303030303030303030303000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000030303030303030303030303030303030303030303
030303030303030303030303030303030303000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000030303030303030303030303030303030303030303
030303030303030303030303030303030303000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ADADADADADADADADADADADAD000000000000
ADADAD000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000030303030303030303030303000000000000030303
000000000000030303030303030303030303000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ADADADADADAD000000000000FFFFFF000000
000000000000FFFFFF000000000000ADADADADADAD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000030303030303000000000000FFFFFF000000000000
000000FFFFFF000000000000030303030303000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000464646464646000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000464646000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000232323232323000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000232323000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADAD000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000ADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000464646464646464646464646464646
000000464646000000000000464646464646464646464646000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676000000
767676000000000000767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000232323232323232323232323232323000000
232323000000000000232323232323232323232323000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADAD000000ADADAD
000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000464646464646464646464646464646
464646464646464646464646464646464646464646464646000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000232323232323232323232323232323232323
232323232323232323232323232323232323232323000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000464646464646464646464646464646
464646464646464646464646464646464646464646464646000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000232323232323232323232323232323232323
232323232323232323232323232323232323232323000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000464646464646464646464646464646
464646464646464646464646464646464646464646464646000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000232323232323232323232323232323232323
232323232323232323232323232323232323232323000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000464646464646464646464646000000
000000464646000000000000464646464646464646464646000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676000000000000
767676000000000000767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000232323232323232323232323000000000000
232323000000000000232323232323232323232323000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADAD000000000000ADADAD
000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000464646464646000000000000FFFFFF
000000000000000000FFFFFF000000000000464646464646000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676000000000000FFFFFF000000
000000000000FFFFFF000000000000767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000232323232323000000000000FFFFFF000000
000000000000FFFFFF000000000000232323232323000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADAD000000000000FFFFFF000000000000
000000FFFFFF000000000000ADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000464646464646000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000464646000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000464646464646464646464646464646000000
464646000000000000464646464646464646464646000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000A9A9A9
000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000464646464646464646464646464646464646
464646464646464646464646464646464646464646000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000464646464646464646464646464646464646
464646464646464646464646464646464646464646000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000464646464646464646464646000000000000
464646000000000000464646464646464646464646000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9000000000000A9A9A9
000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000464646464646000000000000FFFFFF000000
000000000000FFFFFF000000000000464646464646000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9000000000000FFFFFF000000000000
000000FFFFFF000000000000A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000373737000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000AAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000666666666666000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000666666000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
000000C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000666666666666666666666666666666000000666666
000000000000666666666666666666666666000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000666666666666666666666666666666666666666666
666666666666666666666666666666666666000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000666666666666666666666666666666666666666666
666666666666666666666666666666666666000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000666666666666666666666666666666666666666666
666666666666666666666666666666666666000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000
000000C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737000000000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAA000000000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000666666666666666666666666000000000000666666
000000000000666666666666666666666666000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF
000000000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000FFFFFF000000
000000000000FFFFFF000000000000373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000FFFFFF000000
000000000000FFFFFF000000000000AAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000666666666666000000000000FFFFFF000000000000
000000FFFFFF000000000000666666666666000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000959595959595000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000959595000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000009D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000272727272727000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000272727000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000959595959595959595959595959595
000000959595000000000000959595959595959595959595000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000
9D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000272727272727272727272727272727000000
272727000000000000272727272727272727272727000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000959595959595959595959595959595
959595959595959595959595959595959595959595959595000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000272727272727272727272727272727272727
272727272727272727272727272727272727272727000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000959595959595959595959595959595
959595959595959595959595959595959595959595959595000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000272727272727272727272727272727272727
272727272727272727272727272727272727272727000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000959595959595959595959595959595
959595959595959595959595959595959595959595959595000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000272727272727272727272727272727272727
272727272727272727272727272727272727272727000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000959595959595959595959595000000
000000959595000000000000959595959595959595959595000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D000000000000
9D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000272727272727272727272727000000000000
272727000000000000272727272727272727272727000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000959595959595000000000000FFFFFF
000000000000000000FFFFFF000000000000959595959595000000FFFFFF
FFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000FFFFFF000000
000000000000FFFFFF0000000000009D9D9D9D9D9D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000272727272727000000000000FFFFFF000000
000000000000FFFFFF000000000000272727272727000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000001F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
0000001F1F1F0000000000001F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F000000
0000001F1F1F0000000000001F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F000000000000FFFFFF
000000000000000000FFFFFF0000000000001F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000005A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A000000
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000FFFFFF
000000000000000000FFFFFF0000000000005A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF000000
000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000000000
000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000003F3F3F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
0000003F3F3F0000000000003F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F000000
0000003F3F3F0000000000003F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F000000000000FFFFFF
000000000000000000FFFFFF0000000000003F3F3F3F3F3F000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E0000006E6E6E
0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E0000000000006E6E6E
0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000000000
000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999000000000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000FFFFFF000000
000000000000FFFFFF000000000000999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000
000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000000000
000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000007E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
0000008D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000
0000008D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E000000000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF
000000000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000FFFFFF000000
000000000000FFFFFF0000000000007E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000919191000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191000000
919191000000000000919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A0000007A7A7A
0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191919191
919191919191919191919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191919191
919191919191919191919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191919191919191
919191919191919191919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191919191919191000000000000
919191000000000000919191919191919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A0000000000007A7A7A
0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF
000000000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000919191919191000000000000FFFFFF000000
000000000000FFFFFF000000000000919191919191000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000
000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF000000000000
000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000000B0B0B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001B1B1B1B1B1B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000001B1B1B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0000000B0B0B0000000000000B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001B1B1B1B1B1B1B1B1B1B1B1B1B1B1B000000
1B1B1B0000000000001B1B1B1B1B1B1B1B1B1B1B1B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000D0D0D0
000000000000D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0
D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0
D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0
D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B000000
0000000B0B0B0000000000000B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001B1B1B1B1B1B1B1B1B1B1B1B000000000000
1B1B1B0000000000001B1B1B1B1B1B1B1B1B1B1B1B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0000000000000D0D0D0
000000000000D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B000000000000FFFFFF
000000000000000000FFFFFF0000000000000B0B0B0B0B0B000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001B1B1B1B1B1B000000000000FFFFFF000000
000000000000FFFFFF0000000000001B1B1B1B1B1B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000
000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0000000000000FFFFFF000000000000
000000FFFFFF000000000000D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADAD000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000ADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
000000272727000000000000272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADAD000000ADADAD
000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
272727272727272727272727272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
272727272727272727272727272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727272727
272727272727272727272727272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727272727272727000000
000000272727000000000000272727272727272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADAD000000000000ADADAD
000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000272727272727000000000000FFFFFF
000000000000000000FFFFFF000000000000272727272727000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADAD000000000000FFFFFF000000000000
000000FFFFFF000000000000ADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000000B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000171717171717000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000171717000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000
3F3F3F0000000000003F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000
0B0B0B0000000000000B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000171717171717171717171717171717000000171717
000000000000171717171717171717171717000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000171717171717171717171717171717171717171717
171717171717171717171717171717171717000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000171717171717171717171717171717171717171717
171717171717171717171717171717171717000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000171717171717171717171717171717171717171717
171717171717171717171717171717171717000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F000000000000
3F3F3F0000000000003F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B0B0B0B0B0B0B000000000000
0B0B0B0000000000000B0B0B0B0B0B0B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000171717171717171717171717000000000000171717
000000000000171717171717171717171717000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F000000000000FFFFFF000000
000000000000FFFFFF0000000000003F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000B0B0B0B0B0B000000000000FFFFFF000000
000000000000FFFFFF0000000000000B0B0B0B0B0B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000171717171717000000000000FFFFFF000000000000
000000FFFFFF000000000000171717171717000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
156 227 moveto
213 227 lineto
213 4 lineto
156 4 lineto
closepath
fill
gsave
156 227 translate
57 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000CCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
000000CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCC000000
000000CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4000000000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000FFFFFF
000000000000000000FFFFFF000000000000CCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000FFFFFF000000
000000000000FFFFFF000000000000C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF0000004E4E4E4E4E4E000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000004E4E4E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000
7A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E0000004E4E4E
0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A000000000000
7A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E0000000000004E4E4E
0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF
000000000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000
000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF000000
000000000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF0000004E4E4E4E4E4E000000000000FFFFFF000000000000
000000FFFFFF0000000000004E4E4E4E4E4E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
000000A5A5A5000000000000A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313000000
131313000000000000131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313131313
131313131313131313131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313131313
131313131313131313131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5
A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313131313131313
131313131313131313131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5A5A5A5A5A5A5000000
000000A5A5A5000000000000A5A5A5A5A5A5A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313131313131313000000000000
131313000000000000131313131313131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272000000000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000A5A5A5A5A5A5000000000000FFFFFF
000000000000000000FFFFFF000000000000A5A5A5A5A5A5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000131313131313000000000000FFFFFF000000
000000000000FFFFFF000000000000131313131313000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000FFFFFF000000
000000000000FFFFFF000000000000727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000000000
000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000AAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
0000008D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000
A9A9A9000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000BDBDBD
000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000
0000008D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9000000000000
A9A9A9000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAA000000000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000BDBDBD
000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF
000000000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9000000000000FFFFFF000000
000000000000FFFFFF000000000000A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000FFFFFF000000
000000000000FFFFFF000000000000AAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000000000
000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000AAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
0000007A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A000000
0000007A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAA000000000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF
000000000000000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000FFFFFF000000
000000000000FFFFFF000000000000AAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF000000
000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000005A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000004E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000
4E4E4E0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A000000
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E000000000000
4E4E4E0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000FFFFFF
000000000000000000FFFFFF0000000000005A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E000000000000FFFFFF000000
000000000000FFFFFF0000000000004E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000000000
000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000919191919191000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000919191000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000004E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000919191919191919191919191919191
000000919191000000000000919191919191919191919191000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000
4E4E4E0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000919191919191919191919191919191
919191919191919191919191919191919191919191919191000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000919191919191919191919191919191
919191919191919191919191919191919191919191919191000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000919191919191919191919191919191
919191919191919191919191919191919191919191919191000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E
4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000919191919191919191919191000000
000000919191000000000000919191919191919191919191000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E4E4E4E4E4E4E000000000000
4E4E4E0000000000004E4E4E4E4E4E4E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000919191919191000000000000FFFFFF
000000000000000000FFFFFF000000000000919191919191000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004E4E4E4E4E4E000000000000FFFFFF000000
000000000000FFFFFF0000000000004E4E4E4E4E4E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000000000
000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000AAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAA000000000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000FFFFFF000000
000000000000FFFFFF000000000000AAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000
6A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A000000000000
6A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
000000000000000000FFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000FFFFFF000000
000000000000FFFFFF0000000000006A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000000000
000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000CCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
000000CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCC000000
000000CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999000000000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000FFFFFF
000000000000000000FFFFFF000000000000CCCCCCCCCCCC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000FFFFFF000000
000000000000FFFFFF000000000000999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000A9A9A9
000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9000000000000A9A9A9
000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000A9A9A9A9A9A9000000000000FFFFFF000000000000
000000FFFFFF000000000000A9A9A9A9A9A9000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000007E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000007E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
0000007E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E0000006E6E6E
0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E000000
0000007E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E000000000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E0000000000006E6E6E
0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000FFFFFF
000000000000000000FFFFFF0000000000007E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000FFFFFF000000
000000000000FFFFFF0000000000007E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF000000
000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000000000
000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000006A6A6A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000CCCCCC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
0000006A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000
CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A000000
0000006A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCCCCCCCCCCCCCC000000000000
CCCCCC000000000000CCCCCCCCCCCCCCCCCCCCCCCC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000FFFFFF
000000000000000000FFFFFF0000000000006A6A6A6A6A6A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000CCCCCCCCCCCC000000000000FFFFFF000000
000000000000FFFFFF000000000000CCCCCCCCCCCC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000005A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A000000
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4000000000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000FFFFFF
000000000000000000FFFFFF0000000000005A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000FFFFFF000000
000000000000FFFFFF000000000000C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000
000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000000000
000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000ECECEC
000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000ECECEC
000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
000000000000000000FFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000000000
000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E0000006E6E6E
0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E0000000000006E6E6E
0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF000000
000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000000000
000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
0000007A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A000000
0000007A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999000000000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF
000000000000000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000FFFFFF000000
000000000000FFFFFF000000000000999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000000000
000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000007E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
0000008D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000
0000008D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E000000000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF
000000000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000FFFFFF000000
000000000000FFFFFF0000000000007E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000
000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF
000000000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000
000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
000000C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000
000000C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF
000000000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADAD000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000ADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADAD000000ADADAD
000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADADADADADADADADADADAD
ADADADADADADADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADADADADADADADAD000000000000ADADAD
000000000000ADADADADADADADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ADADADADADAD000000000000FFFFFF000000000000
000000FFFFFF000000000000ADADADADADAD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000626262626262000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000626262000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000
3F3F3F0000000000003F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000626262626262626262626262626262000000626262
000000000000626262626262626262626262000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000626262626262626262626262626262626262626262
626262626262626262626262626262626262000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000626262626262626262626262626262626262626262
626262626262626262626262626262626262000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000626262626262626262626262626262626262626262
626262626262626262626262626262626262000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F3F3F3F3F3F3F000000000000
3F3F3F0000000000003F3F3F3F3F3F3F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000626262626262626262626262000000000000626262
000000000000626262626262626262626262000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003F3F3F3F3F3F000000000000FFFFFF000000
000000000000FFFFFF0000000000003F3F3F3F3F3F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000626262626262000000000000FFFFFF000000000000
000000FFFFFF000000000000626262626262000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
234 227 moveto
290 227 lineto
290 4 lineto
234 4 lineto
closepath
fill
gsave
234 227 translate
56 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999000000000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000FFFFFF000000
000000000000FFFFFF000000000000999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF
000000000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000000000
000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000000000
000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000
A9A9A9000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000BDBDBD
000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9000000000000
A9A9A9000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000BDBDBD
000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9000000000000FFFFFF000000
000000000000FFFFFF000000000000A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000
000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000000000
000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000AAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAA000000000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF
000000000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000FFFFFF000000
000000000000FFFFFF000000000000AAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000
C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF
000000000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000
000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000005A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A000000
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000000000C8C8C8
000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000FFFFFF
000000000000000000FFFFFF0000000000005A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF000000000000
000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
000000727272000000000000727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272000000
000000727272000000000000727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272000000000000FFFFFF
000000000000000000FFFFFF000000000000727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000
000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000000000
000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
000000B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000
000000B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF
000000000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A0000007A7A7A
0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A0000000000007A7A7A
0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF000000000000
000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
000000B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000
000000B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF
000000000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
000000B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000
000000B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF
000000000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000000000
000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000007E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000626262626262000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000626262000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
0000007E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000626262626262626262626262626262000000
626262000000000000626262626262626262626262000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000626262626262626262626262626262626262
626262626262626262626262626262626262626262000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000626262626262626262626262626262626262
626262626262626262626262626262626262626262000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000626262626262626262626262626262626262
626262626262626262626262626262626262626262000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E000000
0000007E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000626262626262626262626262000000000000
626262000000000000626262626262626262626262000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000FFFFFF
000000000000000000FFFFFF0000000000007E7E7E7E7E7E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000626262626262000000000000FFFFFF000000
000000000000FFFFFF000000000000626262626262000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000007E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E7E7E7E7E7E7E000000000000
7E7E7E0000000000007E7E7E7E7E7E7E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007E7E7E7E7E7E000000000000FFFFFF000000
000000000000FFFFFF0000000000007E7E7E7E7E7E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
0000006E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000
0000006E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF
000000000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000
000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000000000
000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF000000
000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000FFFFFF000000
FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A0000007A7A7A
0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999000000000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A0000000000007A7A7A
0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000FFFFFF000000
000000000000FFFFFF000000000000999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF000000000000
000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000
000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
0000006E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000
0000006E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000
B5B5B5000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF
000000000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000
000000000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
000000C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8C8C8C8C8C8C8000000
000000C8C8C8000000000000C8C8C8C8C8C8C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000000000
BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C8C8C8C8C8C8000000000000FFFFFF
000000000000000000FFFFFF000000000000C8C8C8C8C8C8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF000000
000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E6E6E6E6E6E6E000000000000
6E6E6E0000000000006E6E6E6E6E6E6E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000006E6E6E6E6E6E000000000000FFFFFF000000
000000000000FFFFFF0000000000006E6E6E6E6E6E000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
306 227 moveto
363 227 lineto
363 4 lineto
306 4 lineto
closepath
fill
gsave
306 227 translate
57 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000009D9D9D000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
0000009D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000
E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D9D9D9D9D9D9D000000
0000009D9D9D0000000000009D9D9D9D9D9D9D9D9D9D9D9D000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000
E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000009D9D9D9D9D9D000000000000FFFFFF
000000000000000000FFFFFF0000000000009D9D9D9D9D9D000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000
000000000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000000000
000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF
000000000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
000000D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000
000000D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF
000000000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000000000
000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF000000
000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000BDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBDBDBDBDBDBDBD000000
000000BDBDBD000000000000BDBDBDBDBDBDBDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000BDBDBDBDBDBD000000000000FFFFFF
000000000000000000FFFFFF000000000000BDBDBDBDBDBD000000FFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF000000
000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000000000
000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
0000003B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000
0000003B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF
000000000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF000000
000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000D0D0D0
000000000000D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0
D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0
D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0
D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0D0D0D0D0D0D0000000000000D0D0D0
000000000000D0D0D0D0D0D0D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D0D0D0D0D0D0000000000000FFFFFF000000000000
000000FFFFFF000000000000D0D0D0D0D0D0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
000000D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000
000000D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF
000000000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000000000
000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000004A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000
4A4A4A0000000000004A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A000000000000
4A4A4A0000000000004A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A000000000000FFFFFF000000
000000000000FFFFFF0000000000004A4A4A4A4A4A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
000000727272000000000000727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272000000
000000727272000000000000727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272000000000000FFFFFF
000000000000000000FFFFFF000000000000727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000000000
000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF000000
000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000000000
000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676000000
767676000000000000767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676767676767676
767676767676767676767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676767676767676000000000000
767676000000000000767676767676767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000767676767676000000000000FFFFFF000000
000000000000FFFFFF000000000000767676767676000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BBBBBBBBBBBB000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000BBBBBB000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BBBBBBBBBBBBBBBBBBBBBBBBBBBBBB000000
BBBBBB000000000000BBBBBBBBBBBBBBBBBBBBBBBB000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB
BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB
BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB
BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BBBBBBBBBBBBBBBBBBBBBBBB000000000000
BBBBBB000000000000BBBBBBBBBBBBBBBBBBBBBBBB000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BBBBBBBBBBBB000000000000FFFFFF000000
000000000000FFFFFF000000000000BBBBBBBBBBBB000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000000000
000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
000000E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000
000000E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737000000000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF
000000000000000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000FFFFFF000000
000000000000FFFFFF000000000000373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000004A4A4A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
0000004A4A4A0000000000004A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000
E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A4A4A4A4A4A4A000000
0000004A4A4A0000000000004A4A4A4A4A4A4A4A4A4A4A4A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000
E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000004A4A4A4A4A4A000000000000FFFFFF
000000000000000000FFFFFF0000000000004A4A4A4A4A4A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000
000000000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000007A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000
7A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A7A7A7A7A7A7A000000000000
7A7A7A0000000000007A7A7A7A7A7A7A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000E4E4E4
000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000007A7A7A7A7A7A000000000000FFFFFF000000
000000000000FFFFFF0000000000007A7A7A7A7A7A000000FFFFFFFFFFFF
FFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000000000
000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
81 488 moveto
138 488 lineto
138 265 lineto
81 265 lineto
closepath
fill
gsave
81 488 translate
57 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000003B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4000000000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B3B3B3B3B3B3B000000000000
3B3B3B0000000000003B3B3B3B3B3B3B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000FFFFFF000000
000000000000FFFFFF000000000000C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000003B3B3B3B3B3B000000000000FFFFFF000000
000000000000FFFFFF0000000000003B3B3B3B3B3B000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000000000
000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000000000
000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000008D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
000000D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000
000000D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D8D8D8D8D8D8D000000000000
8D8D8D0000000000008D8D8D8D8D8D8D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5B5B5B5B5B5B5000000000000B5B5B5
000000000000B5B5B5B5B5B5B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF
000000000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000008D8D8D8D8D8D000000000000FFFFFF000000
000000000000FFFFFF0000000000008D8D8D8D8D8D000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B5B5B5B5B5B5000000000000FFFFFF000000000000
000000FFFFFF000000000000B5B5B5B5B5B5000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000030303030303000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000030303000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F0F0F0F0F0F0000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F0F0F0000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000030303030303030303030303030303
000000030303000000000000030303030303030303030303000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000
F0F0F0000000000000F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000030303030303030303030303030303
030303030303030303030303030303030303030303030303000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0
F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000030303030303030303030303030303
030303030303030303030303030303030303030303030303000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0
F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000030303030303030303030303030303
030303030303030303030303030303030303030303030303000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0
F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000030303030303030303030303000000
000000030303000000000000030303030303030303030303000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0000000000000
F0F0F0000000000000F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000030303030303000000000000FFFFFF
000000000000000000FFFFFF000000000000030303030303000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F0F0F0F0F0F0000000000000FFFFFF000000
000000000000FFFFFF000000000000F0F0F0F0F0F0000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000006A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000
6A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A6A6A6A6A6A6A000000000000
6A6A6A0000000000006A6A6A6A6A6A6A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000006A6A6A6A6A6A000000000000FFFFFF000000
000000000000FFFFFF0000000000006A6A6A6A6A6A000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000
A9A9A9000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9A9A9A9A9A9A9000000000000
A9A9A9000000000000A9A9A9A9A9A9A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000A9A9A9A9A9A9000000000000FFFFFF000000
000000000000FFFFFF000000000000A9A9A9A9A9A9000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000
000000DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF
000000000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F0F0F0F0F0F0000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F0F0F0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000F0F0F0
000000000000F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0
F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0
F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0
F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000
000000E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F0F0F0F0F0F0F0F0F0F0F0F0000000000000F0F0F0
000000000000F0F0F0F0F0F0F0F0F0F0F0F0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF
000000000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F0F0F0F0F0F0000000000000FFFFFF000000000000
000000FFFFFF000000000000F0F0F0F0F0F0000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000070707070707000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000070707000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000070707070707070707070707070707
000000070707000000000000070707070707070707070707000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000070707070707070707070707070707
070707070707070707070707070707070707070707070707000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000070707070707070707070707070707
070707070707070707070707070707070707070707070707000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000070707070707070707070707070707
070707070707070707070707070707070707070707070707000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4
E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000070707070707070707070707000000
000000070707000000000000070707070707070707070707000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4E4E4E4E4E4E4000000000000
E4E4E4000000000000E4E4E4E4E4E4E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000070707070707000000000000FFFFFF
000000000000000000FFFFFF000000000000070707070707000000FFFFFF
FFFFFFFFFFFFFFFFFF000000E4E4E4E4E4E4000000000000FFFFFF000000
000000000000FFFFFF000000000000E4E4E4E4E4E4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000000000
000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737373737373737
373737373737373737373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737373737373737000000000000
373737000000000000373737373737373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000373737373737000000000000FFFFFF000000
000000000000FFFFFF000000000000373737373737000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000373737373737000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000373737000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000373737373737373737373737373737
000000373737000000000000373737373737373737373737000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000373737373737373737373737373737
373737373737373737373737373737373737373737373737000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000373737373737373737373737373737
373737373737373737373737373737373737373737373737000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000373737373737373737373737373737
373737373737373737373737373737373737373737373737000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000373737373737373737373737000000
000000373737000000000000373737373737373737373737000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000373737373737000000000000FFFFFF
000000000000000000FFFFFF000000000000373737373737000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
000000C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000
E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4000000
000000C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000
E8E8E8000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000FFFFFF
000000000000000000FFFFFF000000000000C4C4C4C4C4C4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000
000000000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707000000070707
000000000000070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707000000000000070707
000000000000070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707000000000000FFFFFF000000000000
000000FFFFFF000000000000070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
156 488 moveto
213 488 lineto
213 265 lineto
156 265 lineto
closepath
fill
gsave
156 488 translate
57 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F000000000000000000FFFFFF
000000FFFFFFFFFFFF0000000000000000001F1F1F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000
1F1F1F0000000000001F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F000000000000
1F1F1F0000000000001F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F000000000000FFFFFF000000
000000000000FFFFFF0000000000001F1F1F1F1F1F000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000
000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000000000
000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000DCDCDC
000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000000000
000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000001F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
0000001F1F1F0000000000001F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F1F1F1F1F1F1F000000
0000001F1F1F0000000000001F1F1F1F1F1F1F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000001F1F1F1F1F1F000000000000FFFFFF
000000000000000000FFFFFF0000000000001F1F1F1F1F1F000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000
000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000B1B1B1000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
000000B1B1B1000000000000B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1000000
000000B1B1B1000000000000B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1000000000000FFFFFF
000000000000000000FFFFFF000000000000B1B1B1B1B1B1000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000333333333333000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000333333000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000333333333333333333333333333333
000000333333000000000000333333333333333333333333000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000333333333333333333333333333333
333333333333333333333333333333333333333333333333000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000333333333333333333333333333333
333333333333333333333333333333333333333333333333000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000333333333333333333333333333333
333333333333333333333333333333333333333333333333000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000333333333333333333333333000000
000000333333000000000000333333333333333333333333000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000333333333333000000000000FFFFFF
000000000000000000FFFFFF000000000000333333333333000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF
000000000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
234 488 moveto
290 488 lineto
290 265 lineto
234 265 lineto
closepath
fill
gsave
234 488 translate
56 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000AAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000898989000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989000000
898989000000000000898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAA000000000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989000000000000
898989000000000000898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000FFFFFF000000
000000000000FFFFFF000000000000AAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989000000000000FFFFFF000000
000000000000FFFFFF000000000000898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989000000
898989000000000000898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989000000000000
898989000000000000898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989000000000000FFFFFF000000
000000000000FFFFFF000000000000898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000AAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAAAAAAAAAAAAAA000000000000
AAAAAA000000000000AAAAAAAAAAAAAAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAAAAAAAAAA000000000000FFFFFF000000
000000000000FFFFFF000000000000AAAAAAAAAAAA000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272000000000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000FFFFFF000000
000000000000FFFFFF000000000000727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000DCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDCDCDCDCDCDCDC000000000000
DCDCDC000000000000DCDCDCDCDCDCDCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000DCDCDCDCDCDC000000000000FFFFFF000000
000000000000FFFFFF000000000000DCDCDCDCDCDC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707000000070707
000000000000070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272727272727272
727272727272727272727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707070707070707070707
070707070707070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272727272727272000000000000
727272000000000000727272727272727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707070707070707000000000000070707
000000000000070707070707070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000727272727272000000000000FFFFFF000000
000000000000FFFFFF000000000000727272727272000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000070707070707000000000000FFFFFF000000000000
000000FFFFFF000000000000070707070707000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000858585858585000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000858585000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000858585858585858585858585858585000000858585
000000000000858585858585858585858585000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000858585858585858585858585858585858585858585
858585858585858585858585858585858585000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000858585858585858585858585858585858585858585
858585858585858585858585858585858585000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000858585858585858585858585000000000000858585
000000000000858585858585858585858585000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000858585858585000000000000FFFFFF000000000000
000000FFFFFF000000000000858585858585000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000818181000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181000000
818181000000000000818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181818181
818181818181818181818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181818181
818181818181818181818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181818181
818181818181818181818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181000000000000
818181000000000000818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181000000000000FFFFFF000000
000000000000FFFFFF000000000000818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
000000727272000000000000727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272727272
727272727272727272727272727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272727272727272000000
000000727272000000000000727272727272727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000727272727272000000000000FFFFFF
000000000000000000FFFFFF000000000000727272727272000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000818181000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181000000
818181000000000000818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989000000
898989000000000000898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181818181
818181818181818181818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181818181
818181818181818181818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181818181818181
818181818181818181818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989898989898989
898989898989898989898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181818181818181000000000000
818181000000000000818181818181818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989898989898989000000000000
898989000000000000898989898989898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000818181818181000000000000FFFFFF000000
000000000000FFFFFF000000000000818181818181000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000898989898989000000000000FFFFFF000000
000000000000FFFFFF000000000000898989898989000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000D8D8D8D8D8D8000000000000FFFFFF000000
000000000000FFFFFF000000000000D8D8D8D8D8D8000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
306 488 moveto
363 488 lineto
363 265 lineto
306 265 lineto
closepath
fill
gsave
306 488 translate
57 -223 scale
1 string
81 319 8 [81 0 0 319 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000999999000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999999999999999
999999999999999999999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999999999999999000000000000
999999000000000000999999999999999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000999999999999000000000000FFFFFF000000
000000000000FFFFFF000000000000999999999999000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
000000ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000
000000ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF
000000000000000000FFFFFF000000000000ECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000818181818181000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000818181000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000818181818181818181818181818181
000000818181000000000000818181818181818181818181000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000818181818181818181818181818181
818181818181818181818181818181818181818181818181000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000818181818181818181818181818181
818181818181818181818181818181818181818181818181000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000818181818181818181818181818181
818181818181818181818181818181818181818181818181000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000818181818181818181818181000000
000000818181000000000000818181818181818181818181000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000818181818181000000000000FFFFFF
000000000000000000FFFFFF000000000000818181818181000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8E8E8E8E8E8E8000000000000E8E8E8
000000000000E8E8E8E8E8E8E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000E8E8E8E8E8E8000000000000FFFFFF000000000000
000000FFFFFF000000000000E8E8E8E8E8E8000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000000000
FFFFFF000000FFFFFFFFFFFF0000000000000000005A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A5A5A5A
5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4
C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A5A5A5A5A5A5A000000
0000005A5A5A0000000000005A5A5A5A5A5A5A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4C4C4C4C4C4C4000000000000
C4C4C4000000000000C4C4C4C4C4C4C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005A5A5A5A5A5A000000000000FFFFFF
000000000000000000FFFFFF0000000000005A5A5A5A5A5A000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000C4C4C4C4C4C4000000000000FFFFFF000000
000000000000FFFFFF000000000000C4C4C4C4C4C4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
000000ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000
000000ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF
000000000000000000FFFFFF000000000000ECECECECECEC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4
F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000
000000F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000
D4D4D4000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000
F4F4F4000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4F4F4F4F4F4F4000000000000F4F4F4
000000000000F4F4F4F4F4F4F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF
000000000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFF
FFFFFFFFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000
000000000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000
000000000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFF
FFFFFFFFFFFF000000F4F4F4F4F4F4000000000000FFFFFF000000000000
000000FFFFFF000000000000F4F4F4F4F4F4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B1B1B1B1B1B1000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000B1B1B1000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000B1B1B1
000000000000B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000
ECECEC000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1000000000000B1B1B1
000000000000B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000
000000000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000B1B1B1B1B1B1000000000000FFFFFF000000000000
000000FFFFFF000000000000B1B1B1B1B1B1000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000B1B1B1000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000
B1B1B1000000000000B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1
B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1B1B1B1B1B1B1000000000000
B1B1B1000000000000B1B1B1B1B1B1B1B1B1B1B1B1000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4D4D4D4D4D4D4000000000000D4D4D4
000000000000D4D4D4D4D4D4D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000B1B1B1B1B1B1000000000000FFFFFF000000
000000000000FFFFFF000000000000B1B1B1B1B1B1000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000D4D4D4D4D4D4000000000000FFFFFF000000000000
000000FFFFFF000000000000D4D4D4D4D4D4000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
000000131313000000000000131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
131313131313131313131313131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
131313131313131313131313131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
131313131313131313131313131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313000000
000000131313000000000000131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313000000000000FFFFFF
000000000000000000FFFFFF000000000000131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
000000131313000000000000131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
131313131313131313131313131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
131313131313131313131313131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313131313
131313131313131313131313131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313131313131313000000
000000131313000000000000131313131313131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000131313131313000000000000FFFFFF
000000000000000000FFFFFF000000000000131313131313000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000FCFCFC
000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000000000
000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000
FFFFFF000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000000000FFFFFF
000000FFFFFFFFFFFF000000000000000000FCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECEC000000000000000000FFFFFF000000
FFFFFFFFFFFF000000000000000000ECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECEC000000ECECEC
000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC
FCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECECECECECECECECECECEC
ECECECECECECECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000
000000FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFCFCFCFCFCFCFC000000000000
FCFCFC000000000000FCFCFCFCFCFCFCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECECECECECECECEC000000000000ECECEC
000000000000ECECECECECECECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF
000000000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FCFCFCFCFCFC000000000000FFFFFF000000
000000000000FFFFFF000000000000FCFCFCFCFCFC000000FFFFFFFFFFFF
FFFFFFFFFFFF000000ECECECECECEC000000000000FFFFFF000000000000
000000FFFFFF000000000000ECECECECECEC000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
1 setlinewidth
0 setgray
/R Frutiger Roman findfont 11 scalefont setfont
92 241 moveto (Gen. 0) show
/R Frutiger Roman findfont 11 scalefont setfont
168 241 moveto (Gen. 1) show
/R Frutiger Roman findfont 11 scalefont setfont
245 241 moveto (Gen. 2) show
/R Frutiger Roman findfont 11 scalefont setfont
321 241 moveto (Gen. 4) show
/R Frutiger Roman findfont 11 scalefont setfont
89 500 moveto (Gen. 5) show
/R Frutiger Roman findfont 11 scalefont setfont
163 500 moveto (Gen. 10) show
/R Frutiger Roman findfont 11 scalefont setfont
240 500 moveto (Gen. 15) show
/R Frutiger Roman findfont 11 scalefont setfont
313 500 moveto (Gen. 20) show
%%Trailer
%%EOF
\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{284, 499},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Background->None,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004L0001l`P10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^CLg=gIfM[Fe]OCdm?clo5D005Gooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_C/k>gYjN[Vi^OShn000EED0EJX00?l003lo?ginO[fm_Oclo0<30d92@X61PL30`3lo
?ginO[fm_Ol0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5Q@<30d92@X61PL30`?l0ZP00
oeD0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9R@L71dI6AXF5QLC4a?l0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=S@/;2dY:BXV9RLS8b?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6AT@l?3di>CXf=SLc<c?mEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUA<C4e9B
DY6ATM3@d?mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVALG5eIFEYFEUMCDe?mEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWA/K6eYJFYVIVMSHf?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXAlO7eiNGYfMWMcLg?nZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYB<S8f9RHZ6QXN3Ph?nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZBLW9fIV
IZFUYNCTi?nZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][B/[:fYZJZVYZNSXj?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/Bl_;fi^KZf][Nc/k?ooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]C<c<g9bL[6a/O3`l0000?l07@000?l07@000?l07@000?l07@000?l0
7@000?l07@000?l07@000?l07@000?l07@000?l07@000?l07@000?l07@000?l07@000?l07@000?l0
7@000?l07@000?l07@000?l07@000?l07@000?l07@000?l07@000?l07@0000<01?l00`3o0004o`80
1_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o6004o`030?l000Co0P06o`030?oo00;o0`06o`03
0?oo00;o0P06o`800olK00Go0P03o`<01?l00`3o0003o`@01Ol00`3oo`02ob<01?l00`3o0004o`80
1_l00`3oo`02oa001_l200?o1@0000<000Co3`l?0ol33`04o`00o`<?00?o3ol00`l01Ol0003o00<?
00?o3ol00`l01?l00?l43`?o0Pl00ol0000F0004o`l?3`?o0`l01?l00?l3Z`03oj_o00>[00Go0000
o`033`03o`oo00<?00Co003o12L3o`8W00?o00006@001?lW9bL3o`8W00Go0000o`03`P?o0/800ol0
00020004oeeMG@?o0Ud00ol0000Q0004obLW9`?o0bL01?l00?l39`03obOo00<W00?o00003P000olW
9`029`?o0RL00ol0000300000`000ol?3`073`04o`00o`T?00Go0000o`093`04o`00o`T?00?o0000
5P000ol?3`073`04o`00o`V[00Go0000o`093`04o`00o`TW00?o00006@000olW9`069`05o`000?l0
2<800ol000020003oeeM00IM00?o00008@000olW9`079`04o`00o`TW00?o00003P000olW9`079`03
o`0000<000030003o`l?00L?00Co003o2@l01Ol0003o00T?00Co003o2@l00ol0000F0003o`l?00L?
00Co003o2J/01Ol0003o00T?00Co003o2BL00ol0000I0003obLW00HW00Go0000o`08`P03o`000080
00?oGEd01Ud00ol0000Q0003obLW00LW00Co003o2BL00ol0000>0003obLW00LW00?o00000`0000<0
00?o3`l01?l33`04o`00o`<?00?o3ol00`l01Ol0003o00<?00?o3ol00`l01?l00?l33`Co0Pl00ol0
000F0003o`l?00Co0`l01?l00?l3Z`03oj_o00>[00Go0000o`033`03o`oo00<?00Co003o0bL4o`8W
00?o00006@000olW9`04o`8W00Go0000o`02`PCo0/800ol000020003oeeM00Co0Ud00ol0000Q0003
obLW00Co0bL01?l00?l39`03obOo00<W00?o00003P001?lW9bL4o`8W00?o00000`0000<02ol200_o
0`0;o`802olH00_o0P0;o`<02ol200_o6`0:o`<02_l400[o8`0;o`802ol@00_o1@0000<000?o0?l0
10001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0o`0H0003
o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l0
6`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o00<000Co003o8`000ol0o`040004
o`00o`8000Co003o0`001?l00?l@0004o`00o`@000?o0?l01@000?l07@0000<00_l30004o`0000;o
0P02o`<000Co00000_l300?o0P001?l00002obD00_l30004o`0000;o0P02o`<000Co00000_l@00?o
0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005o`000?l01002o`8000?o0000
0P001?l00002o`<000Go0000o`0a00?o0P001?l00002o`800ol20003o`00008000?o00000`0000<0
00?o3ol01_l01Poo003o3`Oo00<?o`000P000on^o`08obD000?o9ol01_l01ROo003o3`Oo00<?o`00
3`000ol?3`08oa/000?o9ol01ol30003obOo00Oo10000olWo`07o`<000?o9ol01ola0003obOo00So
0P000olW9`08o`D000030003o`l?00L?00Co003o2@l01Ol0003o00V^00?o00008`000olW9`079`04
o`00o`T?00?o00003P000ol?3`073`03o`0001T000?o9bL01RL01Ol0003o00PW00?o00000P000olW
9`069`05o`000?l022L00ol0000_0003obLW00LW00Co003o2BL00ol0000300000`000ol?3`073`04
o`00o`T?00Go0000o`09[P03o`0002<000?o9bL01bL01?l00?l93`03o`0000h000?o3`l01`l00ol0
000I0003obLW00HW00Go0000o`089`03o`00008000?o9bL01RL01Ol0003o00PW00?o0000;`000olW
9`079`04o`00o`TW00?o00000`0000<000?o3`l01?l33`04o`00o`<?00?o3ol00`l01Ol0003o00>^
00?o[_l00jh00ol0000S0003obLW00Co0bL01?l00?l33`03o`oo00<?00?o00003P001?l?3`l4o`8?
00?o00006@000olW9`04o`8W00Go0000o`029`Co0RL00ol000020003obLW00Co0RL01Ol0003o008W
1?l29`03o`0002l000Oo9bLWobOo00<W00Co003o0bL4o`8W00?o00000`0000<000Co3ol00_l01@3o
3`oo008000?o3ol01_l00`oo00020003ojko00Ko00>^o`0090001?lWo`02o`050?lW9ol00P000ol?
o`06o`033ol000l000Go3`oo0002o`040?l?oa/000Co9ol00_l0103o9ol30003obOo00?o00@0obOo
10001?lWo`04o`039ol0008000Co9ol00_l0103o9ola0003obOo00Ko00DWo`00o`029`08o`3oo`3o
9ol500000`04o`801Ol200;o00@0ool01Ol300Go00@0ool00_lU00Co0P05o`800_l0103oo`05oa00
1Ol200Co6`04o`801?l300;o00@0o`001?l400Co0P001?l0ool300Co0P04oc401Ol0103oo`02o`80
1Ol200Co1@000?l07@0001000_l30004o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003
o`0001H00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003o`000080
00?o0000=002o`8000?o00000P001?l00002o`<000Go0000o`0F00;o0`001?l00002o`800_l30004
o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0000<0000@0003o`oo00?o00D0ool?
o`030003obOo00?o00<0ool00_l20003o`l?00?o0P03oaP000Oo9ooo0?l000;o00HWo`00oih4o`05
0?ooW_l00`000ol?o`03o`030?oo00;o0P000ol?3`03o`800olf0003oego00;o00<0ool00_l30007
obOoo`3o0003oaH000Oo9ooo0?l000;o00HWo`00obL4o`050?oo9ol00`000olWo`03o`030?oo00;o
0P000olW9`03o`800ol5000040001ol?3`oo3ol00`l01Ol0003o00<W00?o9ol00bL01?l00?l43`?o
0Pl00ol0000F0004obLW9`?o0bL01?l00?l3WP03oiko00>N00Go0000o`033`03o`oo00<?00Co003o
10l3o`8?00?o0000=0001?mMGEd3o`9M00Go0000o`039`?o0RL00ol0000D0004obLW9`?o0bL01?l0
0?l39`03obOo00<W00Go0000o`039`03obOo00<W00Co003o12L3o`8W00?o00000`00010000?o3`l0
1`l01Ol0003o00TW00Co003o2@l00ol0000F0003obLW00LW00Co003o2Ih01Ol0003o00T?00Co003o
2@l00ol0000d0003oeeM00IM00Go0000o`089`03o`0001@000?o9bL01bL01?l00?l99`05o`000?l0
2BL01?l00?l99`03o`0000<0000@0003o`l?00L?00Go0000o`099`04o`00o`T?00?o00005P000olW
9`079`04o`00o`VN00Go0000o`093`04o`00o`T?00?o0000=0000omMG@06G@05o`000?l022L00ol0
000D0003obLW00LW00Co003o2BL01Ol0003o00TW00Co003o2BL00ol00003000040000ol?o`06o`03
3ol0008000?o9ol01_l01BOo003o008?1_l00`oo000G0003obOo00Go0RL01Ol00?nN00Oo00>No`00
0P000ol?o`06o`053ol00?l00Pl6o`033ol003D000?oGOl01Ol00ego00020003obOo00Go00<Wo`00
5@000olWo`05o`8W00Go003o9`07o`039ol0008000?o9ol01_l01BOo003o008W1_l00bOo00040000
4002o`8000Co0?l00ol300?o00@0o`3o0P02o`800ol01P3o003o00;o6002o`060?l00?l00ol200;o
0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_lf00;o00H0o`00o`02o`<00_l01P3o
003o00;o5P02o`060?l00?l00ol200;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l0
0_l5000040001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l060000ol0
o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o0P001?l00?l40003o`3o03H0
00?o0?l00`001?l00?l30003o`3o00@000?o0?l05P000ol0o`040004o`00o`8000Co003o0`001?l0
0?l30004o`00o`<000Co003o0P001?l00?l40003o`3o00D0003o01d0000300;o0`001?l00002o`80
0_l30004o`0000;o4003o`8000?o00000P000ol0000F00;o0`001?l00002o`800_l30004o`0000;o
0`03o`8000Co00000_l200?o0P000ol000020003o`0003@00_l20003o`00008000?o00008@02o`<0
00Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol000030000
0`000ol?o`06o`063ol00?l?1ol00`oo000?0003o`l?00So60000ol?o`06o`063ol00?lW1ol00bOo
00020003ojko00So0P000on>SP08ocH000?o9ol01olS0003obOo00Ko00HWo`00obL7o`039ol00080
00?oWOl02?l20003obLW00So1@0000<000?o3`l01`l01?l00?l93`03o`0000h000?o3`l01`l00ol0
000F0003o`l?00L?00Co003o2BL01Ol0003o00V^00Co003o2Hh00ol0000d0003obLW00HW00?o0000
8@000olW9`079`04o`00o`TW00Go0000o`09W@04o`00o`TW00?o00000`0000<000?o3`l01`l01?l0
0?l93`03o`0000h000?o3`l01`l00ol0000F0003o`l?00L?00Co003o2BL01Ol0003o00V^00Co003o
2Hh00ol0000d0003obLW00HW00?o00008@000olW9`079`04o`00o`TW00Go0000o`09W@04o`00o`TW
00?o00000`0000<000?o3`l01?l33`04o`00o`<?00?o3ol00`l00ol0000>0004o`l?3`Co0Pl00ol0
000F0003o`l?00Co0`l01?l00?l39`03obOo00<W00Go0000o`03[P03ojko00>^00Co003o0hh4o`:>
00?o0000=0000olW9`04o`8W00?o00008@000olW9`04o`<W00Co003o0bL00olWo`039`05o`000?l0
0id00onMo`03W@04o`00o`<W1?l29`03o`0000<0000300_o0P0;oa002olH00_o0P0;o`<02ol200_o
=P0:ob<02ol200_o0`0;o`802ol500000`000ol0o`040004o`00o`8000Co003o0`001?l00?l@0004
o`00o`@000?o0?l060000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o
0P001?l00?l40003o`3o03H000?o0?l00`001?l00?lS0003o`3o00@000Co003o0P001?l00?l30004
o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l01@000?l07@0000<00_l30004o`0000;o
0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o00005P02o`<000Co0000
0_l@00?o0P001?l00002o`800ol20003o`00008000?o00009P02o`<000Go0000o`0400;o0P000ol0
00020004o`0000;o0`001Ol0003o01H00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l0
0002o`800ol20003o`00008000?o00000`0000<000Oo3ooo0?l000;o00H?o`00odh4o`050?ooC_l0
0`000olLo`03o`030?oo00;o0P000ol?3`03o`800olH0007obOoo`3o0002o`039ol000l000?o9ol0
0ol00`3oo`02o`8000?o9bL00ol200?o:0001olWool0o`000ol40003ol;o00;o00<0ool00_l30007
obOoo`3o0003oaH000Oo9ooo0?l000;o00HWo`00obL4o`050?oo9ol00`000olWo`03o`030?oo00;o
0P000olW9`03o`800ol500000`001?l?3`l3o`<?00Co003o0dh00om>o`03CP05o`000?l00a`00olL
o`037004o`00o`@?0ol23`03o`0001H000Co9bLW0ol39`03o`0000h000Oo9bLWobOo00<W00Co003o
12L3o`8W00?o00009P001?lW9bL3o`8W00?o00000P001?o2`/83o`;200Go0000o`039`?o0RL00ol0
000D0004obLW9`?o0bL01?l00?l39`03obOo00<W00Go0000o`039`03obOo00<W00Co003o12L3o`8W
00?o00000`0000<000?o3`l01`l01?l00?l9CP05o`000?l02A`01?l00?l93`03o`0001H000?o9bL0
1bL00ol0000>0003obLW00LW00Co003o2BL00ol0000V0003obLW00HW00?o00000P000oo2`P06`P05
o`000?l022L00ol0000D0003obLW00LW00Co003o2BL01Ol0003o00TW00Co003o2BL00ol000030000
0`000ol?3`04o`<?00Co003o0dh00om>o`03CP05o`000?l00a`00olLo`037004o`00o`<?1?l23`03
o`0001H000?o9bL01?l39`03o`0000h000Oo9bLWobOo00<W00Co003o0bL4o`8W00?o00009P000olW
9`04o`8W00?o00000P000oo2`P04o`;200Go0000o`029`Co0RL00ol0000D0003obLW00Co0bL01?l0
0?l39`03obOo00<W00Go0000o`039`03obOo00<W00Co003o0bL4o`8W00?o00000`0000<000Co3ol0
0_l01@3o3`oo008000?oC_l01_l00dko00020003oaco00Ko00DLo`00o`023`08o`3oo`3o3olH0004
obOo00;o00D0obLWo`0@0003obOo00Ko00DWo`00o`029`08o`3oo`3o9olX0003obOo00?o00@0obOo
10001?o2o`04o`03`_l0008000Co9ol00_l0103o9olF0004obOo00;o00D0obLWo`020003obOo00Ko
00<Wo`000P000olWo`06o`059ol00?l00RL02?l0ool0obOo1@0000<00_l01P3o003o00?o0P02o`80
00Co0?l00ol300?o00@0o`3o0P02o`800ol01P3o003o00;o6002o`060?l00?l00ol@00?o00@0o`3o
0P02o`800ol01P3o003o00;o:002o`060?l00?l00_l400;o00H0o`00o`02o`<00_l01P3o003o00;o
5P02o`060?l00?l00ol200;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_l50000
0`000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o0P001?l00?l40003
o`3o01P000?o0?l010001?l00?l@0004o`00o`<000Co003o0P001?l00?l40003o`3o02P000Co003o
0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o01H000?o0?l010001?l00?l20004
o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0o`050000o`0M00000`04o`03
0?l000Co0P06o`030?oo00;o0`06o`030?oo00;o0P06o`800olH00Co00<0o`001?l200Ko00<0ool0
0_l300Ko00<0ool00_l200Ko0P03oa/01Ol200?o0`04o`030?l000?o1005o`030?oo00;o0`04o`03
0?l000?o5P04o`030?l000Co0P06o`030?oo00;o0`06o`030?oo00;o0P06o`800ol500000`001?o>
c/h3o`?>00Co003o0`l00ol?o`033`05o`000?l00lh00oo>o`03cP04o`00o`B>0ol2SP03o`0001H0
00Co3`l?0ol33`04o`00o`<?00?o3ol00`l01Ol0003o00<W00?o9ol00bL01?l00?l4[P?o0Zh00ol0
000I0004obLW9`?o0RL01Ol0003o00<W0ol29`03o`00008000Coo?cl0ol2o005o`000?l00bL3o`8W
00?o000050001?o^k^h3o`?^00Co003o0bL00olWo`039`05o`000?l00bL00olWo`039`04o`00o`@W
0ol29`03o`0000<000030003olk>00O>00Co003o2@l01Ol0003o00W>00Co003o2Hh00ol0000F0003
o`l?00L?00Co003o2@l01Ol0003o00TW00Co003o2Jh00ol0000I0003obLW00HW00Go0000o`089`03
o`00008000?oo?`01_`01Ol0003o00PW00?o000050000oo^kP07kP04o`00o`TW00Go0000o`099`04
o`00o`TW00?o00000`0000<000?oc/h01lh01?l00?l93`05o`000?l02Lh01?l00?l9SP03o`0001H0
00?o3`l01`l01?l00?l93`05o`000?l02BL01?l00?l9[P03o`0001T000?o9bL01RL01Ol0003o00PW
00?o00000P000oolo006o005o`000?l022L00ol0000D0003onk^00O^00Co003o2BL01Ol0003o00TW
00Co003o2BL00ol0000300000`000oo>cP04o`?>00Co003o0`l00ol?o`033`05o`000?l00lh00oo>
o`03cP04o`00o`>>1?l2SP03o`0001H000?o3`l01?l33`04o`00o`<?00?o3ol00`l01Ol0003o00<W
00?o9ol00bL01?l00?l3[PCo0Zh00ol0000I0003obLW00Co0RL01Ol0003o008W1?l29`03o`000080
00?oo?`01?l2o005o`000?l00RL4o`8W00?o000050000oo^kP04o`?^00Co003o0bL00olWo`039`05
o`000?l00bL00olWo`039`04o`00o`<W1?l29`03o`0000<0000300_o0P0;o`<02ol200_o600;o`80
2ol300_o0P0;oa/02_l300[o100:o`<02_lF00_o0P0;o`<02ol200_o1@0000<000?o0?l010001?l0
0?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0o`0H0003o`3o00@0
00Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l06`000ol0
o`040003o`3o00<000Co003o0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o01H0
00?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0
o`050000o`0M00004002o`<000Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o0000
8`02o`<000Co00000_l@00?o0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005
o`000?l04@02o`<000Go0000o`0F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co0000
0_lB000040000ol?o`06o`033ol0008000?oS_l02?l20003ohj>00So9@000olWo`06o`039ol000l0
00?o9bL02?lK0003obOo00Oo0`000olWo`07oa4000?o9ol01olF0003ob[o00Ko00HZo`00onh7o`03
k_l0008000?ok_l02?lB000040000ol?3`073`05o`000?l02Hh01?l00?l9SP03o`0002<000?o9bL0
1bL00ol0000>0003obLW00LW00?o00006@000olW9`069`05o`000?l022L00ol0000?0003obLW00HW
00?o000050000olZ:P07:P04o`00o`W^00Go0000o`09kP03o`000100000@0003o`l?00L?00Go0000
o`09SP04o`00o`V>00?o00008`000olW9`079`03o`0000h000?o9bL01bL00ol0000I0003obLW00HW
00Go0000o`089`03o`0000l000?o9bL01RL00ol0000D0003obXZ00LZ00Co003o2Nh01Ol0003o00W^
00?o00004000010000Oo3`l?o`oo00<?00Go0000o`03SP03ohko00>>00Co003o0hh4o`:>00?o0000
8`001olW9bOo9ol00bL00ol0000>0004obLW9`Co0RL00ol0000I0003obLW00Co0RL01Ol0003o008W
1?l29`03o`0000l000?o9bL01?l29`03o`0001@000?o:RX01?l3:P04o`00o`?^00?ok_l00nh01Ol0
003o00?^00?ok_l00nh00ol0000@000040000ol?o`06o`033ol0008000?oS_l01_l01Hko003o00:>
00So0?oo0?n>obD000?o9ol01_l00bOo000?0005obLWo`000_l0103o9olK0004obOo00;o00@0obOo
0`000olWo`03o`040?lWoa4000Co9ol00_l0103o9olF0004ob[o00;o00D0obXZo`020003onko00Ko
00?^o`000P000oo^o`06o`03k_l00140000@00;o00@0ool01Ol300Go00@0ool00_l200Go0P04obD0
0_l0103oo`05oa001Ol200Co6`04o`801?l300;o00@0o`001?lA00Co0P04oaH01?l200Go0P02o`04
0?oo00Go0`05o`040?oo00;o4P000?l07@0000<00_l30004o`0000;o0P02o`<000Co00000_l300?o
0P001?l00002o`800ol20003o`00008000?o00005P02o`<000Co00000_l200;o0`001?l00002o`<0
0ol20004o`0000;o0P03o`8000?o00000P000ol0000I00;o0P000ol000020004o`0000;o0`001Ol0
003o01400_l30005o`000?l05P02o`<000Co00000_l200;o0`001?l00002oa000ol20003o`000080
00?o00000`0000<000OoS_oo0?l000;o00J>o`00o`l4o`050?oo3ol00`000om]o`03o`030?oo00;o
0P000ol61P03o`800olH0007obOoo`3o0002o`069ol00?l?1?l01@3oo`oo00<000?o9ol00ol00`3o
o`02o`8000?o[Zh00ol200?o6`000olWo`02o`800ol30007obOoo`3o0003oa4000Oo9ooo0?l000?o
5P001olWool0o`000_l01ROo003o9`Co00D0oolWo`0@0003o`l?00?o0P03o`D000030004ohj>SP?o
0hh01?l00?l33`03o`oo00<?00Go0000o`03K@03ofgo00=]00Co003o10H3o`8600?o00005P001?lW
9bL3o`<W00Co003o0`l00ol?o`033`05o`000?l00bL00olWo`039`04o`00o`B^0ol2[P03o`0001T0
00Co9bLW0ol29`05o`000?l00bL3o`8W00?o00003`001?lW9bL3o`8W00?o000050001?lW9bL3o`<W
00Co003o0bL00olWo`039`03o`0000h000?o3`l00Pl3o`8?00?o00000`0000<000?oSXh01hh01?l0
0?l93`05o`000?l02Fd01?l00?l91P03o`0001H000?o9bL01bL01?l00?l93`05o`000?l02BL01?l0
0?l9[P03o`0001T000?o9bL01RL01Ol0003o00PW00?o00003`000olW9`069`03o`0001@000?o9bL0
1bL01?l00?l99`03o`0000h000?o3`l01`l00ol0000300000`000on>SP07SP04o`00o`T?00Go0000
o`09K@04o`00o`T600?o00005P000olW9`079`04o`00o`T?00Go0000o`099`04o`00o`V^00?o0000
6@000olW9`069`05o`000?l022L00ol0000?0003obLW00HW00?o000050000olW9`079`04o`00o`TW
00?o00003P000ol?3`073`03o`0000<000030003ohko00Go0Xh01Ol00?l?00Oo00<?o`000P000om]
o`06o`05KOl00?l00PH6o`031_l001L000?o9ol01Ol29`05o`00o`l01ol00`oo00020003obOo00Ko
00DWo`00o`02[PKo00>^o`006P000olWo`05o`039ol0008000?o9ol01Ol00bOo000@0003obOo00Go
00<Wo`005@000olWo`05o`8W00Go003o9`07o`039ol000l000?o3`l01_l00`oo000400000`02o`06
0?l00?l00ol200;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_lH00;o00H0o`00
o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02oa/00_l01P3o003o00;o
0`02o`060?l00?l00_lA00;o00H0o`00o`02oaH00_l01P3o003o00?o0P02o`8000Co0?l00ol@00?o
00H0o`00o`02o`D000030003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l0
0?l20004o`00o`@000?o0?l060000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<0
00Co003o0P001?l00?l40003o`3o01/000?o0?l010000ol0o`030004o`00o`<000?o0?l04@000ol0
o`040003o`3o01H000?o0?l010001?l00?l20004o`00o`<000Co003o40001?l00?l40003o`3o00D0
003o01d0000300Co00<0o`001?l200Ko00<0ool00_l300Ko00<0ool00_lU00Co00<0o`001?lM00Ko
0P03oa/01Ol200?o0`04o`030?l000?o1005o`030?oo00;o0`04o`030?l000?o5P04o`030?l000Co
0P06o`030?oo00;o4006o`800ol500000`001?lk>c/3o`<k00Co003o0oh00oono`03oP05o`000?l0
0`l00ol?o`033`03o`0002<000Co9bLW0ol39`03o`0001/000?o3`l00Pl3o`8?00?o00006@001?lW
9bL3o`8W00Go0000o`03[P?o0Zh00ol000020004obLW9`?o0RL01Ol0003o00<W0ol29`03o`0001@0
00Co9bLW0ol39`04o`00o`?^00?ok_l00nh00ol0000>0003obLW008W0ol29`03o`0000<000030003
oc/k00Lk00Co003o2Oh01Ol0003o00T?00?o00008`000olW9`079`03o`0001/000?o3`l01`l00ol0
000I0003obLW00HW00Go0000o`08[P03o`00008000?o9bL01RL01Ol0003o00PW00?o000050000olW
9`079`04o`00o`W^00?o00003P000olW9`079`03o`0000<000030003oc/k00Lk00Co003o2Oh01Ol0
003o00T?00?o00008`000olW9`079`03o`0001/000?o3`l01`l00ol0000I0003obLW00HW00Go0000
o`08[P03o`00008000?o9bL01RL01Ol0003o00PW00?o000050000olW9`079`04o`00o`W^00?o0000
3P000olW9`079`03o`0000<000030003oc/k00Co0c/01?l00?l3oP03ooko00?n00Go0000o`033`03
o`oo00<?00?o00008`000olW9`04o`<W00?o00006`001?l?3`l4o`8?00?o00006@000olW9`04o`8W
00Go0000o`02[PCo0Zh00ol000020003obLW00Co0RL01Ol0003o008W1?l29`03o`0001@000?o9bL0
1?l39`04o`00o`?^00?ok_l00nh00ol0000>0004obLW9`Co0RL00ol0000300000`0;o`802ol300_o
9@0;oad02olK00[o0`0:o`@02_l300[o5P0;o`802ol@00_o1@0000<000?o0?l010001?l00?l20004
o`00o`<000Co003o0`001?l00?l30004o`00obD000?o0?l010001?l00?lM0004o`00o`@000?o0?l0
6`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003
o`3o01H000?o0?l010001?l00?l20004o`00o`<000Co003o40001?l00?l40003o`3o00D0003o01d0
000300;o0`001?l00002o`800_l30004o`0000;o<`02o`<000Co00000_l200;o0`001?l00002o`<0
0ol20004o`0000;o0P03o`8000?o00000P000ol0000I00;o0P000ol000020004o`0000;o0`001Ol0
003o00@00_l20003o`00008000Co00000_l30005o`000?l08`02o`<000Co00000_l@00?o0P000ol0
00020003o`0000<000030007o`ooo`3o0002o`063ol00?oL1?l01@3oomco03<000Oo3ooo0?l000;o
00H?o`00obL4o`050?oo9ol00`000ol?o`03o`030?oo00;o0P000ol?3`03o`800olK0003obOo00;o
0P03o`<000Oo9ooo0?l000?o10000on^o`02o`030?oo00;o0`001olWool0o`000olS0003onko00?o
00D0ooo^o`0@0003omkN00?o0P03o`D000030004o`l?3`?o0`l01?l00?l3g003omco00?L00?o0000
<@001?l?3`l3o`<?00Co003o0bL00olWo`039`05o`000?l00`l00ol?o`033`04o`00o`@?0ol23`03
o`0001T000Co9bLW0ol29`05o`000?l00bL3o`8W00?o00000P001?n^[Zh3o`:^00Go0000o`039`?o
0RL00ol0000Q0007onk^k_o^o`03kP03o`0000h000?og]h00]h3o`;N00?o00000`0000<000?o3`l0
1`l01?l00?l9g003o`00034000?o3`l01`l01?l00?l99`05o`000?l02@l01?l00?l93`03o`0001T0
00?o9bL01RL01Ol0003o00PW00?o00000P000on^[P06[P05o`000?l022L00ol0000Q0003onk^00O^
00?o00003P000ooNgP07gP03o`0000<000030003o`l?00Co0`l01?l00?l3g003omco00?L00?o0000
<@000ol?3`04o`<?00Co003o0bL00olWo`039`05o`000?l00`l00ol?o`033`04o`00o`<?1?l23`03
o`0001T000?o9bL01?l29`05o`000?l00RL4o`8W00?o00000P000on^[P04o`:^00Go0000o`029`Co
0RL00ol0000Q0007onk^k_o^o`03kP03o`0000h000Cog]kN1?l2gP03o`0000<000030004o`oo00;o
00D0o`l?o`020003omco00Ko00?Lo`00<P001?l?o`02o`050?l?3ol00P000olWo`06o`039ol00080
00?o3ol01_l01@oo003o008?00So0?oo0?l?oa/000Co9ol00_l0103o9ol30003obOo00?o00@0obOo
10001?n^o`04o`03[_l0008000Co9ol00_l0103o9olS0003onko00Ko00?^o`003`001OoNg_l000;o
00@0omko1@0000<01?l200Go0P02o`040?oo00Go<`04o`801Ol200;o00@0ool01Ol300Go00@0ool0
0_l200Go0P04oa/01?l200Co0`02o`040?l000Co1004o`8000Co0?oo0`04o`801?lS00;o00@0ool0
1Ol@00Go0P04o`D0003o01d0003o01d0000@00Ko00<0ool00_l300Ko00<0ool00_l200Ko0P03oaP0
1?l00`3o0004o`801_l00`3oo`02o`<01_l00`3oo`02obP01Ol200?o0`04o`030?l000?o4@04o`03
0?l000?o5P04o`030?l000Co0P06o`030?oo00;o0`06o`030?oo00;o4P00010000OoSXj>ohko00>>
00Go0000o`033`03o`oo00<?00Co003o12L3o`8W00?o00005P001?l?3`l3o`<?00Co003o0`l00ol?
o`033`05o`000?l00bL00olWo`039`03o`0002H000Co9bLW0ol29`05o`000?l00bL3o`8W00?o0000
3`001?lW9bL3o`8W00?o000050001?nLW9`3o`>L00Co003o0hh00on>o`03SP05o`000?l00dh00om>
o`03CP03o`000100000@0003ohj>00N>00Go0000o`093`04o`00o`TW00?o00005P000ol?3`073`04
o`00o`T?00Go0000o`099`03o`0002H000?o9bL01RL01Ol0003o00PW00?o00003`000olW9`069`03
o`0001@000?oW9`01i`01?l00?l9SP05o`000?l02Dh00ol0000@000040000on>SP07SP05o`000?l0
2@l01?l00?l99`03o`0001H000?o3`l01`l01?l00?l93`05o`000?l02BL00ol0000V0003obLW00HW
00Go0000o`089`03o`0000l000?o9bL01RL00ol0000D0003oibL00NL00Co003o2Hh01Ol0003o00U>
00?o00004000010000?oS_l01_l00hko00020003o`oo00Ko00D?o`00o`029`Ko00<Wo`005`000ol?
o`05o`8?00Go003o3`07o`033ol0008000?o9ol01_l00bOo000W0003obOo00Go00<Wo`000P000olW
o`05o`039ol0010000?o9ol01Ol00bOo000E0003oico00Go0Y`01Ol00?n>00Oo00>>o`000P000om>
o`06o`03C_l00140000@00;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_lH00;o
00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_lX00;o00H0o`00o`02o`<00_l01P3o
003o00;o4@02o`060?l00?l00_lF00;o00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`80
0_lB000040001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l060000ol0
o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o:0000ol0o`040003o`3o00<0
00Co003o0`000ol0o`0A0003o`3o00@000?o0?l05P000ol0o`040004o`00o`8000Co003o0`001?l0
0?l30004o`00o`<000Co003o4P000?l07@0001000_l30004o`0000;o0`03o`8000Co00000_l200?o
0P000ol000020003o`0001H00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002obP0
0_l20003o`00008000Co00000_l30005o`000?l01002o`8000?o00000P001?l00002o`<000Go0000
o`0F00;o0`001?l00002o`800_l30004o`0000;o4003o`8000?o00000P000ol00003000040000ol?
o`06o`033ol0008000?o[_l02?l20003o`l?00So60000olWo`06o`069ol00?l?1ol00`oo00020003
o`oo00So:0000olWo`07o`<000?oo?l01ol40003obOo00Oo0`000om;o`07oaH000?ok_l01_l01^ko
003o9`Oo00<Wo`003`000olW9`08o`D0000@0003o`l?00L?00Go0000o`09[P04o`00o`T?00?o0000
5P000olW9`079`04o`00o`T?00Go0000o`093`03o`0002H000?o9bL01RL01Ol0003o00Sl00?o0000
0P000olW9`069`05o`000?l024/00ol0000D0003onk^00O^00Co003o2BL00ol0000>0003obLW00LW
00?o00000`00010000?o3`l01`l01Ol0003o00V^00Co003o2@l00ol0000F0003obLW00LW00Co003o
2@l01Ol0003o00T?00?o00009P000olW9`069`05o`000?l02?`00ol000020003obLW00HW00Go0000
o`08B`03o`0001@000?ok^h01nh01?l00?l99`03o`0000h000?o9bL01bL00ol00003000040001ol?
3`oo3ol00`l01Ol0003o00>^00?o[_l00jh01?l00?l33`Co0Pl00ol0000F0003obLW00Co0bL01?l0
0?l33`03o`oo00<?00Go0000o`033`03o`oo00<?00?o00009P000olW9`04o`8W00Go0000o`02o0Co
0_`00ol000020003obLW00Co0RL01Ol0003o009;1?l2B`03o`0001@000?ok^h01?l3kP04o`00o`<W
00?o9ol00bL00ol0000>0004obLW9`Co0RL00ol00003000040000ol?o`06o`033ol0008000?o[_l0
1_l01Jko003o008?00So0?oo0?l?oaP000Co9ol00_l01@3o9bOo008000?o3ol01_l00`oo00020003
o`oo00Ko00<?o`009`001?lWo`02o`040?lWo`<000?oo?l00ol0103oo?l40004obOo00Co00<Wo`00
0P001?m;o`02o`040?m;oaH000Cok_l00_l01@3ok^ko008000?o9ol01_l00bOo000?0005obLWo`00
0_l0103o9ol500004002o`040?oo00Go0`05o`040?oo00;o0P05o`801?lH00Co0P05o`800_l0103o
o`05o`<01Ol0103oo`02obP01?l200Co0`02o`040?l000Co1004o`8000Co0?oo0`04o`801?lF00Co
0P05o`800_l0103oo`05oa001Ol200Co1@000?l07@000?l07@0000<00_l30004o`0000;o4003o`80
00Co00000_l200?o0P000ol000020003o`0001H00_l30004o`0000;o0P02o`<000Co00000_l@00?o
0P000ol000020003o`0001T00_l20003o`00008000?o00003`02o`8000?o00000P001?l00002o`<0
00Go0000o`0F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co00000_lB00000`000ol?
o`06o`033ol000l000?ogOl02?l20003o`l?00So60000olWo`06o`069ol00?l?1ol00`oo000?0003
obLW00So6`000olWo`07oa4000?o9ol01ol30003odgo00Oo5P000olWo`06o`069ol00?lW1ol00bOo
00020003obOo00So4P0000<000?o3`l01`l00ol0000>0003omgM00OM00Co003o2@l00ol0000F0003
obLW00LW00Co003o2@l00ol0000>0003obLW00LW00?o00006@000olW9`069`03o`0000l000?o9bL0
1RL01Ol0003o00Q=00?o000050000olW9`079`04o`00o`TW00Go0000o`099`03o`00010000030003
o`l?00L?00?o00003P000ooMg@07g@04o`00o`T?00?o00005P000olW9`079`04o`00o`T?00?o0000
3P000olW9`079`03o`0001T000?o9bL01RL00ol0000?0003obLW00HW00Go0000o`08C@03o`0001@0
00?o9bL01bL01?l00?l99`05o`000?l02BL00ol0000@00000`000ol?o`05o`8?00?o00003P000ooM
o`06o`05gOl00?l00Pl6o`033ol001L000?o9ol01Ol29`05o`00o`l01ol00`oo000?0003obLW00Ko
00<Wo`006P000olWo`05o`039ol0010000?o9ol01Ol00bOo00020003odgo00Go00==o`005@000olW
o`05o`8W00Go003o9`07o`039ol0008000?o9ol01_l00bOo000A00000`02o`060?l00?l00ol@00?o
00@0o`3o0P02o`800ol01P3o003o00;o6002o`060?l00?l00ol200;o0P001?l0o`03oa000ol01P3o
003o00;o6`02o`060?l00?l00_lA00;o00H0o`00o`02o`<00_l01P3o003o00;o5P02o`060?l00?l0
0ol200;o0P001?l0o`03o`<00ol0103o0?l200;o4P0000<000?o0?l010001?l00?l@0004o`00o`<0
00Co003o0P001?l00?l40003o`3o01P000?o0?l010001?l00?l20004o`00o`<000Co003o40001?l0
0?l40003o`3o01/000?o0?l010000ol0o`0A0003o`3o00<000Co003o0`000ol0o`040003o`3o01H0
00?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00oa80003o01d0000300;o
0`001?l00002o`800_l30004o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0001H0
0_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002ocD00_l30005o`000?l01002o`80
00?o00000P001?l00002o`<000Go0000o`0F00;o0`001?l00002o`800_l30004o`0000;o0`03o`80
00Co00000_lB00000`001on^ool0o`000_l01Zko003o[PCo00D0oon^o`030003obOo00?o00<0ool0
0_l20003o`l?00?o0P03oaP000Oo9ooo0?l000;o00HWo`00obL4o`050?oo9ol00`000olWo`03o`03
0?oo00;o=@001olWool0o`000ol40003obOo00;o00<0ool00_l30007obOoo`3o0003oaH000Oo9ooo
0?l000;o00HWo`00onh4o`050?ook_l00`000oo^o`03o`030?oo00;o4P0000<000Co[Zj^0ol3[P04
o`00o`>^00?o[_l00jh01Ol0003o00<W00?o9ol00bL01?l00?l43`?o0Pl00ol0000F0004obLW9`?o
0bL01?l00?l39`03obOo00<W00Go0000o`039`03obOo00<W00?o0000<`001?lW9bL3o`8W00?o0000
0P001?lW9bL3o`8W00Go0000o`039`?o0RL00ol0000D0004obLW9`?o0bL01?l00?l3kP03onko00?^
00Go0000o`03kP03onko00?^00?o0000400000<000?o[Zh01jh01?l00?l9[P05o`000?l02BL01?l0
0?l93`03o`0001H000?o9bL01bL01?l00?l99`05o`000?l02BL00ol0000c0003obLW00HW00?o0000
0P000olW9`069`05o`000?l022L00ol0000D0003obLW00LW00Co003o2Nh01Ol0003o00W^00?o0000
400000<000?o[Zh01jh01?l00?l9[P05o`000?l02BL01?l00?l93`03o`0001H000?o9bL01bL01?l0
0?l99`05o`000?l02BL00ol0000c0003obLW00HW00?o00000P000olW9`069`05o`000?l022L00ol0
000D0003obLW00LW00Co003o2Nh01Ol0003o00W^00?o0000400000<000?o[_l01Ol2[P05o`00ojh0
1ol00jko00020003obOo00Ko00DWo`00o`023`Ko00<?o`005`000olWo`05o`8W00Go003o9`07o`03
9ol0008000?o9ol01_l00bOo000d0003obOo00Go00<Wo`000`000olWo`05o`039ol0008000?o9ol0
1Ol00bOo000E0003obOo00Go0RL01Ol00?o^00Oo00?^o`000P000oo^o`06o`03k_l00140000300;o
00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02oaP00_l01P3o
003o00?o0P02o`8000Co0?l00ol300?o00@0o`3o0P02ocD00_l01P3o003o00;o1002o`060?l00?l0
0_l300;o00H0o`00o`02oaH00_l01P3o003o00?o0P02o`8000Co0?l00ol300?o00@0o`3o0P02oa80
00030003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@0
00?o0?l060000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o=@001?l0
0?l30003o`3o00@000?o0?l00`001?l00?l30003o`3o00@000?o0?l05P000ol0o`040004o`00o`80
00Co003o0`001?l00?l30004o`00o`<000Co003o4P000?l07@0001h00ol20004o`0000;o0P03o`80
00?o00000P000ol0000F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co00000_lX00;o
0P000ol000020004o`0000;o0`001Ol0003o00@00_l20003o`00008000Co00000_l30005o`000?l0
5P02o`<000Co00000_l@00?o0P001?l00002o`800ol20003o`00008000?o00000`0001h000?o3ol0
2?l20003ojj^00So60000on[o`06o`06Zol00?l?1ol00`oo00020003oiko00So:0000olWo`07o`<0
00?o9ol01ol40003onko00Oo0`000olWo`07oaH000?o9ol01_l00bOo000?0003obOo00So0P000olW
9`08o`D0000N0003o`l?00L?00Co003o2Jh00ol0000F0003oj^[00N[00Co003o2@l01Ol0003o00VN
00?o00009P000olW9`069`05o`000?l022L00ol000020003onk^00K^00Go0000o`089`03o`0001@0
00?o9bL01bL00ol0000>0003obLW00LW00Co003o2BL00ol0000300007P000ol?3`073`04o`00o`V^
00?o00005P000on[Z`07Z`04o`00o`T?00Go0000o`09WP03o`0002H000?o9bL01RL01Ol0003o00PW
00?o00000P000oo^kP06kP05o`000?l022L00ol0000D0003obLW00LW00?o00003P000olW9`079`04
o`00o`TW00?o00000`0001h000Oo3`l?o`oo00<?00Co003o0jh4o`:^00?o00005P000on[Z`04o`>[
00Co003o0`l00ol?o`033`05o`000?l00ih00onNo`03WP03o`0002H000?o9bL01?l29`05o`000?l0
0RL4o`8W00?o00000P000oo^kP04o`;^00Go0000o`029`Co0RL00ol0000D0003obLW00Co0bL00ol0
000>0007obLW9olWo`039`04o`00o`<W1?l29`03o`0000<0000N00_o0P0;oaP02ol200_o0`0;obP0
2_l300[o100:o`<02_lF00_o400;o`802ol500007P001?l00?l30004o`00o`8000Co003o10000ol0
o`0H0003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?lX0003o`3o00@0
00?o0?l00`001?l00?l30003o`3o00@000?o0?l00`001?l00?l30003o`3o00@000?o0?l05P000ol0
o`040004o`00oa0000Co003o0`001?l00?l20004o`00o`@000?o0?l01@000?l07@0000<00_l30004
o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o00005P02o`<0
00Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol0000I00;o
0P000ol000020004o`0000;o0`001Ol0003o00@00_l20003o`00008000Co00000_l30005o`000?l0
5P02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol0
000300000`001oo>ool0o`000_l01/ko003o3`Co00D0ool?o`030003o`oo00?o00<0ool00_l20003
o`l?00?o0P03oaP000Oo9ooo0?l000;o00HWo`00obL4o`050?oo9ol00`000olWo`03o`030?oo00;o
0P000ol?3`03o`800olK0003obOo00;o0P03o`<000Oo9ooo0?l000?o10000olWo`02o`030?oo00;o
0`001olWool0o`000olF0007o`ooo`3o0002o`063ol00?n>1?l01@3oohko00<000?o3ol00ol00`3o
o`02o`8000?o3`l00ol200?o1@0000<000Coc/k>0ol3cP04o`00o`<?00?o3ol00`l01Ol0003o00<?
00?o3ol00`l01?l00?l43`?o0Pl00ol0000F0004obLW9`?o0bL01?l00?l39`03obOo00<W00Go0000
o`039`03obOo00<W00Co003o10l3o`8?00?o00006@001?lW9bL3o`8W00Go0000o`039`?o0RL00ol0
00020004obLW9`?o0RL01Ol0003o00<W0ol29`03o`0001@000Co3`l?0ol33`04o`00o`>>00?oS_l0
0hh01Ol0003o00<?00?o3ol00`l01?l00?l43`?o0Pl00ol0000300000`000oo>cP07cP04o`00o`T?
00Go0000o`093`04o`00o`T?00?o00005P000olW9`079`04o`00o`TW00Go0000o`099`04o`00o`T?
00?o00006@000olW9`069`05o`000?l022L00ol000020003obLW00HW00Go0000o`089`03o`0001@0
00?o3`l01`l01?l00?l9SP05o`000?l02@l01?l00?l93`03o`0000<000030003olk>00Co0lh01?l0
0?l33`03o`oo00<?00Go0000o`033`03o`oo00<?00Co003o0`l4o`8?00?o00005P000olW9`04o`<W
00Co003o0bL00olWo`039`05o`000?l00bL00olWo`039`04o`00o`<?1?l23`03o`0001T000?o9bL0
1?l29`05o`000?l00RL4o`8W00?o00000P000olW9`04o`8W00Go0000o`029`Co0RL00ol0000D0003
o`l?00Co0`l01?l00?l3SP03ohko00>>00Go0000o`033`03o`oo00<?00Co003o0`l4o`8?00?o0000
0`0000<000Coc_l00_l01@3oc/ko008000?o3ol01_l00`oo00020003o`oo00Ko00D?o`00o`023`08
o`3oo`3o3olH0004obOo00;o00D0obLWo`020003obOo00Ko00<Wo`000P000olWo`06o`059ol00?l0
0Pl02?l0ool0o`oo6`001?lWo`02o`040?lWo`<000?o9ol00ol0103o9ol40004obOo00Co00<Wo`00
0P001?lWo`02o`040?lWoaH000Co3ol00_l01@3o3`oo008000?oS_l01_l00hko00020003o`oo00Ko
00D?o`00o`023`08o`3oo`3o3ol500000`02o`060?l00?l00ol200;o0P001?l0o`03o`<00ol0103o
0?l200;o0P03o`060?l00?l00_lH00;o00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`80
0_l200?o00H0o`00o`02oa/00_l01P3o003o00;o0`02o`060?l00?l00_l400;o00H0o`00o`02o`<0
0_l01P3o003o00;o5P02o`060?l00?l00ol200;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`06
0?l00?l00_l500000`000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o
0P001?l00?l40003o`3o01P000?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004
o`00o`8000Co003o10000ol0o`0K0003o`3o00@000?o0?l00`001?l00?l30003o`3o00@000?o0?l0
0`001?l00?l30003o`3o00@000?o0?l05P000ol0o`040004o`00o`8000Co003o0`001?l00?l30004
o`00o`<000Co003o0P001?l00?l40003o`3o00D0003o01d0000300Co00<0o`001?l@00Ko00<0ool0
0_l200Ko0P03oaP01?l00`3o0004o`801_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o6`05o`80
0ol300Co00<0o`000olA00Co00<0o`000olF00Co00<0o`001?l200Ko00<0ool00_l300Ko00<0ool0
0_l200Ko0P03o`D000030004olk>cP?o0lh00ol0000>0007o`l?3ol?o`033`04o`00o`Cn0ol2oP03
o`0001H000CooOgm0ol3o@04o`00o`<W00?o9ol00bL01Ol0003o00<?00?o3ol00`l01?l00?l49`?o
0RL00ol0000I0004obLW9`?o0RL01Ol0003o00<W0ol29`03o`0000l000Co9bLW0ol29`03o`0001@0
00Co9bLW0ol39`04o`00o`<W00?o9ol00bL01Ol0003o00<W00?o9ol00bL01?l00?l49`?o0RL00ol0
000300000`000oo>cP07cP03o`0000h000?o3`l01`l01?l00?l9oP03o`0001H000?ooOd01od01?l0
0?l99`05o`000?l02@l01?l00?l99`03o`0001T000?o9bL01RL01Ol0003o00PW00?o00003`000olW
9`069`03o`0001@000?o9bL01bL01?l00?l99`05o`000?l02BL01?l00?l99`03o`0000<000030003
olk>00O>00?o00003P000ol?3`073`04o`00o`Wn00?o00005P000oomo@07o@04o`00o`TW00Go0000
o`093`04o`00o`TW00?o00006@000olW9`069`05o`000?l022L00ol0000?0003obLW00HW00?o0000
50000olW9`079`04o`00o`TW00Go0000o`099`04o`00o`TW00?o00000`0000<000?oc/h01?l3cP03
o`0000h000Oo3`l?o`oo00<?00Co003o0oh4o`;n00?o00005P000oomo@04o`?m00Co003o0bL00olW
o`039`05o`000?l00`l00ol?o`033`04o`00o`<W1?l29`03o`0001T000?o9bL01?l29`05o`000?l0
0RL4o`8W00?o00003`000olW9`04o`8W00?o000050000olW9`04o`<W00Co003o0bL00olWo`039`05
o`000?l00bL00olWo`039`04o`00o`<W1?l29`03o`0000<0000300_o400;o`802olH00_o0P0;o`<0
2ol200_o6`0:o`<02_lA00[o5P0;o`802ol300_o0P0;o`D000030003o`3o00@000Co003o40001?l0
0?l30004o`00o`8000Co003o10000ol0o`0H0003o`3o00@000Co003o0P001?l00?l30004o`00o`<0
00Co003o0`001?l00?l20004o`00o`@000?o0?l06`000ol0o`040003o`3o00<000Co003o0`000ol0
o`0A0003o`3o00@000?o0?l05P000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<0
00Co003o0P001?l00?l40003o`3o00D0003o01d0000300;o0`001?l00002o`800_l30004o`0000;o
4003o`8000?o00000P000ol0000F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co0000
0_l200?o0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005o`000?l01002o`80
00?o00000P001?l00002o`<000Go0000o`0F00;o0`001?l00002o`800_l30004o`0000;o0`03o`80
00Co00000_lB00000`000ol?o`06o`063ol00?l?1ol00`oo000?0003o`l?00So60000ooko`06o`06
nol00?lW1ol00bOo00020003o`oo00So0P000ol?3`08oa/000?o9ol01ol30003obOo00Oo10000olZ
o`07o`<000?o9ol01olF0003obOo00Ko00HWo`00obL7o`039ol0008000?ok_l02?lB00000`000ol?
3`073`04o`00o`T?00?o00003P000ol?3`073`03o`0001H000?ono/01o/01?l00?l99`05o`000?l0
2@l01?l00?l93`03o`0001T000?o9bL01RL01Ol0003o00PW00?o00000P000olZ:P06:P05o`000?l0
22L00ol0000D0003obLW00LW00Co003o2BL01Ol0003o00W^00?o0000400000<000?o3`l01`l01?l0
0?l93`03o`0000h000?o3`l01`l00ol0000F0003oo_k00Ok00Co003o2BL01Ol0003o00T?00Co003o
2@l00ol0000I0003obLW00HW00Go0000o`089`03o`00008000?o:RX01RX01Ol0003o00PW00?o0000
50000olW9`079`04o`00o`TW00Go0000o`09kP03o`00010000030003o`l?00Co0`l01?l00?l33`03
o`oo00<?00?o00003P001?l?3`l4o`8?00?o00005P000ookn`04o`?k00Co003o0bL00olWo`039`05
o`000?l00`l00ol?o`033`04o`00o`<?1?l23`03o`0001T000?o9bL01?l29`05o`000?l00RL4o`8W
00?o00000P000olZ:P04o`8Z00Go0000o`029`Co0RL00ol0000D0003obLW00Co0bL01?l00?l39`03
obOo00<W00Go0000o`03kP03onko00?^00?o0000400000<000Co3ol00_l01@3o3`oo008000?o3ol0
1_l00`oo000?0005o`l?o`000_l0103o3olH0004oo_o00;o00D0oo_ko`020003obOo00Ko00<Wo`00
0P000ol?o`06o`053ol00?l00Pl02?l0ool0o`oo6`001?lWo`02o`040?lWo`<000?o9ol00ol0103o
9ol40004ob[o00Co00<Zo`000P001?lWo`02o`040?lWoaH000Co9ol00_l01@3o9bOo008000?o9ol0
1_l00bOo00020003onko00Ko00?^o`004@0000<01?l200Go0P02o`040?oo00Go4005o`801?lH00Co
0P05o`800_l0103oo`05o`<01Ol0103oo`02o`801Ol200Co6`04o`801?l300;o00@0o`001?l400Co
0P001?l0ool300Co0P04oaH01?l200Go0P02o`040?oo00Go0`05o`040?oo00;o4P000?l07@0000<0
0_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o0000
?P03o`8000?o00000P000ol0000I00;o0P000ol000020004o`0000;o0`001Ol0003o03400_l30004
o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o00000`0000<0
00Oo3ooo0?l000;o00H?o`00o`l4o`050?oo3ol00`000ol?o`03o`030?oo00;o0P000ol?3`03o`80
0om00003obLW00?o0P03oa/000?o9ol00_l200?o0`001olWool0o`000ola0007obOoo`3o0002o`06
9ol00?lW1?l01@3oobOo00<000?ok_l00ol00`3oo`02o`8000?ooOd00ol200?o1@0000<000Co3`l?
0ol33`04o`00o`<?00?o3ol00`l01Ol0003o00<?00?o3ol00`l01?l00?l43`?o0Pl00ol0000n0003
obLW008W0ol29`03o`0001T000Co9bLW0ol29`05o`000?l00bL3o`8W00?o0000;`001?lW9bL3o`<W
00Co003o0bL00olWo`039`05o`000?l00nh00oo^o`03kP04o`00o`Cm0ol2o@03o`0000<000030003
o`l?00L?00Co003o2@l01Ol0003o00T?00Co003o2@l00ol0000n0003obLW00LW00?o00006@000olW
9`069`05o`000?l022L00ol0000_0003obLW00LW00Co003o2BL01Ol0003o00W^00Co003o2Od00ol0
000300000`000ol?3`073`04o`00o`T?00Go0000o`093`04o`00o`T?00?o0000?P000olW9`079`03
o`0001T000?o9bL01RL01Ol0003o00PW00?o0000;`000olW9`079`04o`00o`TW00Go0000o`09kP04
o`00o`Wm00?o00000`0000<000?o3ol01Ol23`05o`00o`l01ol00`oo00020003o`oo00Ko00D?o`00
o`023`Ko00<?o`00?`000olW9`06o`039ol001X000?o9ol01Ol00bOo00020003obOo00Go00<Wo`00
<0000olWo`05o`8W00Go003o9`07o`039ol0008000?ok_l01_l01Nko003o00;m1_l00ogo00040000
0`02o`060?l00?l00ol200;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_m000?o
00H0o`00o`02oa/00_l01P3o003o00;o0`02o`060?l00?l00_la00;o00H0o`00o`03o`800_l20004
o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02o`D000030003o`3o00@000Co003o0P001?l0
0?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l0@0001?l00?l40003o`3o01/0
00?o0?l010000ol0o`030004o`00o`<000?o0?l0<@000ol0o`040004o`00o`8000Co003o0`001?l0
0?l30004o`00o`<000Co003o0P001?l00?l40003o`3o00D0003o01d0000300Co00<0o`001?l200Ko
00<0ool00_lc00Co00<0o`001?l200Ko00<0ool00_l300Ko00<0ool00_lX00Go0P03oa401Ol00`3o
o`02o`<01?l00`3o0003oaH01?l00`3o0004o`801_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o
1@0000<000CoBd];0ol3B`04o`00o`?>00?oc_l00lh00ol0000a0004o`l?3`?o0`l01?l00?l39`03
obOo00<W00Go0000o`033`03o`oo00<?00?o00009P001?olo?`3o`;l00?o00003`001?lW9bL3o`8W
00Go0000o`039`?o0RL00ol0000D0004obLW9`?o0bL01?l00?l3o@03oogo00?m00Go0000o`039`03
obOo00<W00Co003o18h3o`:>00?o00000`0000<000?oBd/01d/01?l00?l9cP03o`00034000?o3`l0
1`l01?l00?l99`05o`000?l02@l00ol0000V0003oocl00Kl00?o00003`000olW9`069`05o`000?l0
22L00ol0000D0003obLW00LW00Co003o2Od01Ol0003o00TW00Co003o2Hh00ol0000300000`000om;
B`07B`04o`00o`W>00?o0000<@000ol?3`073`04o`00o`TW00Go0000o`093`03o`0002H000?oo?`0
1_`00ol0000?0003obLW00HW00Go0000o`089`03o`0001@000?o9bL01bL01?l00?l9o@05o`000?l0
2BL01?l00?l9SP03o`0000<000030003od];00Co0d/01?l00?l3cP03olko00?>00?o0000<@000ol?
3`04o`<?00Co003o0bL00olWo`039`05o`000?l00`l00ol?o`033`03o`0002H000?oo?`01?l2o003
o`0000l000?o9bL01?l29`05o`000?l00RL4o`8W00?o000050000olW9`04o`<W00Co003o0od00oom
o`03o@05o`000?l00bL00olWo`039`04o`00o`>>1?l2SP03o`0000<0000300_o0P0;oc<02ol200_o
0`0;obP02_lA00[o0`0:oaH02ol200_o0`0;o`802ol500000`000ol0o`040004o`00o`8000Co003o
0`001?l00?lc0003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?lX0003
o`3o00@000?o0?l04@000ol0o`030004o`00o`<000?o0?l010000ol0o`0F0003o`3o00@000Co003o
0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l01@000?l07@000100
0_l30004o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0001H00_l30004o`0000;o
4003o`8000Co00000_l200?o0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005
o`000?l01002o`8000?o00000P001?l00002o`<000Go0000o`0F00;o0`001?l00002oad00ol20003
o`00008000?o00000`00010000?o3ol00ol01@3oo`oo00<000?o3ol00ol00`3oo`02o`8000?oWYh0
0ol200?o60001ol?ool0o`000_l00`oo000?0003o`oo00?o00<0ool00_l20003o`l?00?o0P03oa/0
00?o9ol00_l200?o0`001olWool0o`000ol40003obOo00;o00<0ool00_l30007obOoo`3o0003oaH0
00OoJ?oo0?l000;o00=Xo`0070000olW9`03o`800ol5000040001ol?3`oo3ol00`l01Ol0003o00<?
00?o3ol00`l01?l00?l4WP?o0Yh00ol0000F0004o`l?3`?o0`l00ol0000>0007o`l?3ol?o`033`04
o`00o`@?0ol23`03o`0001T000Co9bLW0ol29`05o`000?l00bL3o`8W00?o00000P001?lW9bL3o`8W
00Go0000o`039`?o0RL00ol0000D0004ofQXJ0?o0fP00ol0000K0003obLW008W0ol29`03o`0000<0
000@0003o`l?00L?00Go0000o`093`04o`00o`VN00?o00005P000ol?3`073`03o`0000h000?o3`l0
1`l01?l00?l93`03o`0001T000?o9bL01RL01Ol0003o00PW00?o00000P000olW9`069`05o`000?l0
22L00ol0000D0003ofQX00MX00?o00006`000olW9`079`03o`0000<0000@0007o`l?3ol?o`033`05
o`000?l00`l00ol?o`033`04o`00o`>N1?l2WP03o`0001H000?o3`l01?l33`03o`0000h000Oo3`l?
o`oo00<?00Co003o0`l4o`8?00?o00006@000olW9`04o`8W00Go0000o`029`Co0RL00ol000020003
obLW00Co0RL01Ol0003o008W1?l29`03o`0001@000?oJ6P01?l3J003o`0001/000Co9bLW1?l29`03
o`0000<0000@0003o`oo00Ko00<?o`000P000ol?o`06o`053ol00?l00Yh02?l0ool0oiko60001?l?
o`02o`050?l?3ol040000ol?o`06o`053ol00?l00Pl02?l0ool0o`oo6`001?lWo`02o`040?lWo`<0
00?o9ol00ol0103o9ol40004obOo00Co00<Wo`000P001?lWo`02o`040?lWoaH000CoJ?l00_l01@3o
J6So01d000Go9bOo0002o`040?lWo`D0000@00;o00@0ool01Ol300Go00@0ool00_l200Go0P04oaP0
1?l200Go4005o`040?oo00;o0P05o`801?lK00Co0P04o`<00_l0103o0004o`@01?l20004o`3oo`<0
1?l200Co5P04o`801OlM00Go0P04o`D0003o01d0003o01d0000@00Ko00<0ool00_l300Ko00<0ool0
0_l200Ko0P03oaP01?l00`3o0004o`801_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o:004o`03
0?l000?o1005o`030?oo00;o0`04o`030?l000?o5P04o`030?l000Co4006o`030?oo00;o0P06o`80
0ol5000040001on^[Zko[_l00jh01Ol0003o00<400?o1?l00`@01?l00?l43`?o0Pl00ol0000F0004
obLW9`?o0bL01?l00?l39`03obOo00<W00Go0000o`033`03o`oo00<?00Co003o12L3o`8W00?o0000
9P001?lW9bL3o`8W00?o00000P001?lW9bL3o`8W00Go0000o`039`?o0RL00ol0000D0004ofQXJ0?o
0fP00ol0000>0007obLW9olWo`039`04o`00o`@W0ol29`03o`0000<0000@0003ojj^00N^00Go0000
o`091004o`00o`T?00?o00005P000olW9`079`04o`00o`TW00Go0000o`093`04o`00o`TW00?o0000
9P000olW9`069`03o`00008000?o9bL01RL01Ol0003o00PW00?o000050000omXJ007J003o`0000h0
00?o9bL01bL01?l00?l99`03o`0000<0000@0003ojj^00N^00Go0000o`091004o`00o`T?00?o0000
5P000olW9`079`04o`00o`TW00Go0000o`093`04o`00o`TW00?o00009P000olW9`069`03o`000080
00?o9bL01RL01Ol0003o00PW00?o000050000omXJ007J003o`0000h000?o9bL01bL01?l00?l99`03
o`0000<0000@0003ojko00Ko00>^o`000P000ol4o`06o`051?l00?l00Pl6o`033ol001L000?o9ol0
1Ol29`05o`00obL01ol00bOo00020003o`oo00Ko00D?o`00o`029`Ko00<Wo`009`000olWo`05o`03
9ol000<000?o9ol01Ol00bOo00020003obOo00Go00<Wo`005@000omXo`05o`9X00?o00003P000olW
o`06o`059ol00?l00RL6o`039ol000@0000@00;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`06
0?l00?l00_lH00;o00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00
o`02obP00_l01P3o003o00;o1002o`060?l00?l00_l300;o00H0o`00o`02oaH00_l01P3o003o00?o
4003o`040?l0o`800_l200?o00H0o`00o`02o`D0000@0004o`00o`<000Co003o0`001?l00?l30004
o`00o`8000Co003o10000ol0o`0H0003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o
0`001?l00?l20004o`00o`@000?o0?l0:0001?l00?l30003o`3o00@000?o0?l00`001?l00?l30003
o`3o00@000?o0?l05P000ol0o`040004o`00oa0000Co003o0`001?l00?l20004o`00o`@000?o0?l0
1@000?l07@0000<00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003
o`00008000?o00005P02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`80
00?o00000P000ol0000I00;o0P000ol000020004o`0000;o0`001Ol0003o00@00_l20003o`000080
00Co00000_l30005o`000?l05P02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o
0P03o`8000?o00000P000ol0000300000`000ol4o`06o`061?l00?lW1ol00bOo00020003o`oo00So
0P000ol?3`08oaP000?o3ol01_l01Poo003o3`Oo00<?o`000P000olWo`08o`8000?o9bL02?lK0003
obOo00Oo0`000olZo`07o`@000?oGOl01ol30003obOo00Oo5P000olWo`06o`069ol00?lW1ol00bOo
00020003obOo00So0P000olW9`08o`D000030003o`@400L400Co003o2BL01Ol0003o00T?00Co003o
2@l00ol0000F0003o`l?00L?00Co003o2@l01Ol0003o00TW00Co003o2BL00ol0000I0003obLW00HW
00Go0000o`08:P03o`00008000?oGEd01Ud01Ol0003o00PW00?o000050000olW9`079`04o`00o`TW
00Go0000o`099`04o`00o`TW00?o00000`0000<000?o10@01`@01?l00?l99`05o`000?l02@l01?l0
0?l93`03o`0001H000?o3`l01`l01?l00?l93`05o`000?l02BL01?l00?l99`03o`0001T000?o9bL0
1RL01Ol0003o00PZ00?o00000P000omMG@06G@05o`000?l022L00ol0000D0003obLW00LW00Co003o
2BL01Ol0003o00TW00Co003o2BL00ol0000300000`000ol41004o`<400Co003o0bL00olWo`039`05
o`000?l00`l00ol?o`033`04o`00o`<?1?l23`03o`0001H000?o3`l01?l33`04o`00o`<?00?o3ol0
0`l01Ol0003o00<W00?o9ol00bL01?l00?l39`Co0RL00ol0000I0003obLW00Co0RL01Ol0003o008Z
1?l2:P03o`00008000?oGEd01?l2G@05o`000?l00RL4o`8W00?o000050000olW9`04o`<W00Co003o
0bL00olWo`039`05o`000?l00bL00olWo`039`04o`00o`<W1?l29`03o`0000<000030004o`Co00;o
00D0o`@4o`020003obOo00Ko00<Wo`000P000ol?o`06o`053ol00?l00Pl02?l0ool0o`oo60001?l?
o`02o`050?l?3ol00P000ol?o`06o`033ol0008000?o9ol01_l01BOo003o008W00So0?oo0?lWoa/0
00Co9ol00_l0103o9ol30003ob[o00?o00@0ob[o10001?mMo`04o`03GOl0008000Co9ol00_l0103o
9olF0004obOo00;o00D0obLWo`020003obOo00Ko00<Wo`000P000olWo`06o`059ol00?l00RL02?l0
ool0obOo1@0000<01?l200Go0P02o`040?oo00Go0`05o`040?oo00;o0P05o`801?lH00Co0P05o`80
0_l0103oo`05o`<01Ol0103oo`02o`801Ol200Co6`04o`801?l300;o00@0o`001?l400Co0P001?l0
ool300Co0P04oaH01?l200Go0P02o`040?oo00Go0`05o`040?oo00;o0P05o`801?l50000o`0M0000
0`02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol0
000F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co00000_le00;o0`001Ol0003o00@0
0_l20003o`00008000Co00000_l30005o`000?l05P02o`<000Co00000_lM00?o0P000ol000020003
o`0000<000030007odkoo`3o0002o`06C_l00?l?1?l01@3oo`oo00<000?og_l00ol00`3oo`02o`80
00?o3`l00ol200?o60001ol?ool0o`000_l01Poo003o9`Co00D0oolWo`030003o`oo00?o00<0ool0
0_le0007obOoo`3o0003o`@000?o9ol00_l00`3oo`02o`<000Oo9ooo0?l000?o5P001olWool0o`00
0_l00bOo000L0003obLW00?o0P03o`D000030004odi>CP?o0dh01?l00?l33`03o`oo00<?00Go0000
o`03gP03omko00?N00Co003o10l3o`8?00?o00005P001?l?3`l3o`<?00Co003o0bL00olWo`039`05
o`000?l00`l00ol?o`033`03o`0003<000Co9bLW0ol29`03o`00008000Co9bLW0ol29`05o`000?l0
0bL3o`8W00?o000050001?lW9bL3o`<W00?o00006`000olW9`029`?o0RL00ol0000300000`000om>
CP07CP04o`00o`T?00Go0000o`09gP04o`00o`T?00?o00005P000ol?3`073`04o`00o`TW00Go0000
o`093`03o`0003<000?o9bL01RL00ol000020003obLW00HW00Go0000o`089`03o`0001@000?o9bL0
1bL00ol0000K0003obLW00LW00?o00000`0000<000?oCTh01dh01?l00?l93`05o`000?l02Mh01?l0
0?l93`03o`0001H000?o3`l01`l01?l00?l99`05o`000?l02@l00ol0000c0003obLW00HW00?o0000
0P000olW9`069`05o`000?l022L00ol0000D0003obLW00LW00?o00006`000olW9`079`03o`0000<0
00030003odko00Go0Th01Ol00?l?00Oo00<?o`000P000ooNo`06o`05g_l00?l00Pl6o`033ol001L0
00?o3ol01Ol23`05o`00obL01ol00bOo00020003o`oo00Ko00<?o`00=0000olWo`05o`039ol000<0
00?o9ol01Ol00bOo00020003obOo00Go00<Wo`005@000olWo`05o`8W00?o00006`000olW9`06o`03
9ol000@0000300;o00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00
o`02oaP00_l01P3o003o00?o0P02o`8000Co0?l00ol300?o00@0o`3o0P02ocD00_l01P3o003o00;o
1002o`060?l00?l00_l300;o00H0o`00o`02oaH00_l01P3o003o00?o7@03o`060?l00?l00_l50000
0`000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o0P001?l00?l40003
o`3o01P000?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00ocD000Co003o
0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o01H000?o0?l010001?l00?lM0004
o`00o`@000?o0?l01@000?l07@0000<01?l00`3o0004o`801_l00`3oo`02oa001_l200?o6004o`03
0?l000Co0P06o`030?oo00;o@`04o`030?l000?o1005o`030?oo00;o0`04o`030?l000?o5P04o`03
0?l000Co0P06o`030?oo00;o0`06o`030?oo00;o0P06o`800ol500000`001?l?3`l3o`<?00Co003o
0`l00ol?o`033`03o`0000h000?oBd/00T/3o`9;00?o00005P001?nNWYh3o`>N00Co003o0`l00ol?
o`033`03o`00044000Co9bLW0ol29`03o`00008000CoWYjN0ol2WP05o`000?l00bL3o`8W00?o0000
50001?lW9bL3o`<W00Co003o0bL00olWo`039`05o`000?l00bL00olWo`039`04o`00o`C^0ol2kP03
o`0000<000030003o`l?00L?00Co003o2@l00ol0000>0003od];00M;00?o00005P000onNWP07WP04
o`00o`T?00?o0000@@000olW9`069`03o`00008000?oWYh01Yh01Ol0003o00PW00?o000050000olW
9`079`04o`00o`TW00Go0000o`099`04o`00o`W^00?o00000`0000<000?o3`l01`l01?l00?l93`03
o`0000h000?oBd/01d/00ol0000F0003oijN00NN00Co003o2@l00ol000110003obLW00HW00?o0000
0P000onNWP06WP05o`000?l022L00ol0000D0003obLW00LW00Co003o2BL01Ol0003o00TW00Co003o
2Nh00ol0000300000`000ol?3`04o`<?00Co003o0`l00ol?o`033`03o`0000h000CoBd];1?l2B`03
o`0001H000?oWYh01?l3WP04o`00o`<?00?o3ol00`l00ol000110003obLW00Co0RL00ol000020003
oijN00Co0Yh01Ol0003o008W1?l29`03o`0001@000?o9bL01?l39`04o`00o`<W00?o9ol00bL01Ol0
003o00<W00?o9ol00bL01?l00?l3kPCo0^h00ol0000300000`0;o`802ol@00_o600;o`802om300[o
100:o`<02_lF00_o0P0;o`<02ol200_o1@0000<000?o0?l010001?l00?l20004o`00o`<000Co003o
40001?l00?l40003o`3o01P000?o0?l010001?l00?l20004o`00o`<000Co003o@`001?l00?l30003
o`3o00@000?o0?l00`001?l00?l30003o`3o00@000?o0?l05P000ol0o`040004o`00o`8000Co003o
0`001?l00?l30004o`00o`<000Co003o0P001?l00?l40003o`3o00D0003o01d0003o01d0003o01d0
003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0
003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0
003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0
003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0
003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0003o01d0000300Co
00<0o`001?l@00Ko00<0ool00_l200Ko0P03oaP01?l00`3o0004oa001_l00`3oo`02od<01Ol00`3o
o`02ob<01?l00`3o0004oa001_l00`3oo`02o`801_l200?o1@0000<000CoKVi^0ol3KP03o`0000h0
00OoCTi>odko00=>00Co003o10@3o`8400?o00005P001?m^KVh3o`=^00?o00003P001om>CTkoC_l0
0dh00ol000110004oifMW@?o0Yd00ol0000Q0004ojf][@?o0jd00ol0000>0007omkNg_oNo`03gP04
o`00o`@60ol21P03o`0000<000030003ofi^00M^00?o00003P000om>CP07CP04o`00o`T400?o0000
5P000om^KP07KP03o`0000h000?oCTh01dh00ol000110003oifM00JM00?o00008@000on][@07[@03
o`0000h000?og]h01mh01?l00?l91P03o`0000<000030003ofi^00M^00?o00003P000om>CP07CP04
o`00o`T400?o00005P000om^KP07KP03o`0000h000?oCTh01dh00ol000110003oifM00JM00?o0000
8@000on][@07[@03o`0000h000?og]h01mh01?l00?l91P03o`0000<000030003ofi^00Co0fh00ol0
000>0007odi>C_m>o`03CP04o`00o`<41?l21003o`0001H000?oKVh01?l3KP03o`0000h000OoCTi>
odko00=>00?o0000@@000onMW@04o`:M00?o00008@000on][@04o`>]00?o00003P001ooNg]kog_l0
0mh01?l00?l31PCo0PH00ol0000300000`0;oa002ol200_o600;oa002om300[o8`0;oa002ol200_o
1@0000<000?o0?l010001?l00?l@0004o`00o`<000Co003o0P001?l00?l40003o`3o01P000?o0?l0
10001?l00?l@0004o`00o`<000Co003o@`000ol0o`030004o`00ob<000?o0?l010001?l00?l@0004
o`00o`<000Co003o0P001?l00?l40003o`3o00D0003o01d0000300;o0`001?l00002o`800_l30004
o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0001H00_l30004o`0000;o0P02o`<0
00Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o00006@02o`8000?o00000P000ol0
000L00;o0`001Ol0003o01H00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`80
0ol20003o`00008000?o00000`0000<000?oW_l01_l01Yko003oG0Oo00=Lo`000P000olMo`08o`80
00?o10@02?lH0003oiko00Ko00JNo`00on`7o`03k?l0008000?o7Ol02?l20003ofa/00So6`000onN
o`07oah000?o3ol01olF0003oiko00Ko00JNo`00ojh7o`03[_l0008000?o[_l02?l20003o`l?00So
1@0000<000?oWYh01ih01?l00?l9G005o`000?l02Ad01?l00?l91003o`0001H000?oWYh01ih01?l0
0?l9k005o`000?l02Ad01?l00?l9K003o`0001T000?oWYh01Yh00ol0000L0003o`l?00H?00?o0000
50000onNWP07WP04o`00o`V^00Go0000o`09[P04o`00o`T?00?o00000`0000<000?oWYh01ih01?l0
0?l9G005o`000?l02Ad01?l00?l91003o`0001H000?oWYh01ih01?l00?l9k005o`000?l02Ad01?l0
0?l9K003o`0001T000?oWYh01Yh00ol0000L0003o`l?00H?00?o000050000onNWP07WP04o`00o`V^
00Go0000o`09[P04o`00o`T?00?o00000`0000<000?oWYh01?l3WP04o`00o`=L00?oG?l00e`01Ol0
003o00<M00?o7Ol00ad01?l00?l310Co0P@00ol0000F0003oijN00Co0ih01?l00?l3k003onco00?/
00Go0000o`037@03oago00<M00Co003o0f`4o`9/00?o00006@000onNWP04o`:N00?o000070000ol?
3`04o`8?00?o000050000onNWP04o`>N00Co003o0jh00on^o`03[P05o`000?l00jh00on^o`03[P04
o`00o`<?1?l23`03o`0000<000030004oiko00;o00D0oijNo`020003oeco00Ko00=Lo`000P000olM
o`06o`057Ol00?l00P@02?l0ool0o`Co60001?nNo`02o`050?nNW_l00P000oo/o`06o`03k?l00080
00?o7Ol01_l01Ago003o009/00So0?oo0?m/oa/000CoW_l00_l0103oW_lN0004o`oo00;o00@0o`oo
5P001?nNo`02o`050?nNW_l00P000on^o`06o`03[_l0008000?o[_l01_l01Jko003o008?00So0?oo
0?l?o`D0000300Co0P05o`800_l0103oo`05o`<01Ol0103oo`02o`801Ol200Co6004o`801Ol200;o
00@0ool01Ol300Go00@0ool00_l200Go0P04oa/01?l200Co7P04o`801?lF00Co0P05o`800_l0103o
o`05o`<01Ol0103oo`02o`801Ol200Co1@000?l07@0000<00_l30004o`0000;o0P02o`<000Co0000
0_l@00?o0P000ol000020003o`0001H00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l0
0002o`800ol20003o`00008000?o00009P02o`<000Go0000o`0400;o0P000ol000020004o`0000;o
0`001Ol0003o01H00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003
o`00008000?o00000`0000<000OocOoo0?l000;o00K=o`00ofP4o`050?ooJ?l040000om;B`03o`80
0olH0007olgoo`3o0002o`06cOl00?mX1?l01@3oofSo00<000?oo?l00ol00`3oo`02o`8000?oGUh0
0ol200?o:0001omNool0o`000ol40003ojko00;o00<0ool00_l30007oekoo`3o0003oaH000OoS_oo
0?l000;o00J>o`00o`l4o`050?oo3ol00`000ol?o`03o`030?oo00;o0P000ol?3`03o`800ol50000
0`001?o=cLd3o`?=00Co003o0fP00omXo`03J003o`0000h000?oBd/00T/3o`9;00?o00005P001?o=
cLd3o`?=00Co003o0fP00omXo`03J005o`000?l00o`00oolo`03o004o`00o`AN0ol2GP03o`0002H0
00CoGUiN0ol2GP03o`00008000Co[Zj^0ol2[P05o`000?l00eh3o`9N00?o000050001?n>SXh3o`>>
00Co003o0`l00ol?o`033`05o`000?l00`l00ol?o`033`04o`00o`@?0ol23`03o`0000<000030003
olg=00O=00Co003o2FP00ol0000>0003od];00M;00?o00005P000oo=c@07c@04o`00o`UX00Go0000
o`09o004o`00o`UN00?o00009P000omNGP06GP03o`00008000?o[Zh01Zh01Ol0003o00QN00?o0000
50000on>SP07SP04o`00o`T?00Go0000o`093`04o`00o`T?00?o00000`0000<000?ocLd01ld01?l0
0?l9J003o`0000h000?oBd/01d/00ol0000F0003olg=00O=00Co003o2FP01Ol0003o00Wl00Co003o
2Eh00ol0000V0003oeiN00IN00?o00000P000on^[P06[P05o`000?l025h00ol0000D0003ohj>00N>
00Co003o2@l01Ol0003o00T?00Co003o2@l00ol0000300000`000oo=o`05o`;=00Go003oJ007o`03
J?l000l000?oBd/01_l00d_o000G0003olgo00Go0/d01Ol00?mX00Oo00=Xo`000P000oolo`06o`05
o?l00?l00Uh6o`03G_l002L000?oG_l01Ol00eko00030003ojko00Go00>^o`000P000omNo`05o`03
G_l001D000?oS_l01Ol2SP05o`00o`l01ol00`oo00020003o`oo00Ko00D?o`00o`023`Ko00<?o`00
100000<00_l01P3o003o00?o0P02o`8000Co0?l00ol@00?o00H0o`00o`02oaP00_l01P3o003o00?o
0P02o`8000Co0?l00ol300?o00@0o`3o0P02o`800ol01P3o003o00;o:002o`060?l00?l00_l400;o
00H0o`00o`02o`<00_l01P3o003o00;o5P02o`060?l00?l00ol200;o0P001?l0o`03o`<00ol0103o
0?l200;o0P03o`060?l00?l00_l500000`000ol0o`040004o`00o`8000Co003o0`001?l00?l@0004
o`00o`@000?o0?l060000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o
0P001?l00?l40003o`3o02P000Co003o0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003
o`3o01H000?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o
10000ol0o`050000o`0M00000`02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o
0P03o`8000?o00000P000ol0000F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co0000
0_lX00;o0P000ol000020004o`0000;o0`001Ol0003o00@00_l20003o`00008000Co00000_l30005
o`000?l0?P03o`8000?o00000P000ol0000300000`000om>o`06o`06C_l00?mN1ol00eko00020003
ojgo00So0P000olL7008oaP000?o3ol01_l01Poo003oGPOo00=No`000P000omNo`08obP000?o3ol0
1ol30003ojko00Oo10000omNo`07o`<000?og_l01oln0003omkN00So1@0000<000?oCTh01dh01?l0
0?l9GP05o`000?l02Jd01?l00?l97003o`0001H000?o3`l01`l01?l00?l9GP05o`000?l02Eh00ol0
000V0003o`l?00H?00Go0000o`08[P03o`00008000?oGUh01Uh01Ol0003o00SN00?o0000?0000ooN
gP07gP03o`0000<000030003odi>00M>00Co003o2Eh01Ol0003o00V]00Co003o2A`00ol0000F0003
o`l?00L?00Co003o2Eh01Ol0003o00UN00?o00009P000ol?3`063`05o`000?l02:h00ol000020003
oeiN00IN00Go0000o`08gP03o`0003`000?og]h01mh00ol0000300000`000om>CP04o`=>00Co003o
0eh00omNo`03GP05o`000?l00jd00on]o`03[@04o`00o`<L1?l27003o`0001H000?o3`l01?l33`04
o`00o`=N00?oG_l00eh01Ol0003o00=N00?oG_l00eh00ol0000V0003o`l?00Co0Pl01Ol0003o00:^
1?l2[P03o`00008000?oGUh01?l2GP05o`000?l00]h4o`;N00?o0000?0001?oNg]h4o`;N00?o0000
0`0000<02ol200_o0`0;o`802olH00_o0P0;o`<02olX00[o0`0:o`@02_l300[o?P0;o`D000030003
o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l0
60000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o:0000ol0o`040003
o`3o00<000Co003o0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o03h000Co003o
10000ol0o`050000o`0M00000`02o`<000Co00000_l@00?o0P001?l00002o`800ol20003o`000080
00?o00005P02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o0000
0P000ol0000V00;o0`001Ol0003o00@00_l20003o`00008000Co00000_l30005o`000?l05P02o`<0
00Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol000030000
0`001ol^ool0o`000_l00bko000?0003of[o00?o00<0ool00_l20003obh^00?o0P03oaP000OoKOoo
0?l000;o00I]o`00omd4o`050?oogOl00`000oo2o`03o`030?oo00;o0P000ol^;P03o`800olX0007
omgoo`3o0003o`@000?ok?l00_l00`3oo`02o`<000Oo;_oo0?l000?o5P001ol?ool0o`000_l01Poo
003oSPCo00D0oon>o`030003oaco00?o00<0ool00_l20003o`l?00?o0P03o`D000030004obh^;P?o
0bh00ol0000>0007ofYZJ_mZo`03JP04o`00o`@^0ol2;P03o`0001H000CoKFe]0ol3K@04o`00o`?M
00?ogOl00md01Ol0003o00?200?o`_l00l801?l00?l4;P?o0Rh00ol0000V0004omgMg@?o0]d00ol0
00020004onc/k0?o0^`01Ol0003o00<^0ol2;P03o`0001@000Co3`l?0ol33`04o`00o`>>00?oS_l0
0hh01Ol0003o00<L00?o7?l00a`01?l00?l43`?o0Pl00ol0000300000`000ol^;P07;P03o`0000h0
00?oJVX01fX01?l00?l9;P03o`0001H000?oKFd01fd01?l00?l9g@05o`000?l02L801?l00?l9;P03
o`0002H000?ogMd01]d00ol000020003onc/00K/00Go0000o`08;P03o`0001@000?o3`l01`l01?l0
0?l9SP05o`000?l02A`01?l00?l93`03o`0000<000030003obh^00Co0bh00ol0000>0007ofYZJ_mZ
o`03JP04o`00o`<^1?l2;P03o`0001H000?oKFd01?l3K@04o`00o`?M00?ogOl00md01Ol0003o00?2
00?o`_l00l801?l00?l3;PCo0Rh00ol0000V0003omgM00Co0]d00ol000020003onc/00Co0^`01Ol0
003o008^1?l2;P03o`0001@000?o3`l01?l33`04o`00o`>>00?oS_l00hh01Ol0003o00<L00?o7?l0
0a`01?l00?l33`Co0Pl00ol0000300000`001?l^o`02o`050?l^;_l040000omZo`06o`05J_l00?l0
0Rh02?l0ool0obko60001?m]o`02o`050?m]KOl00P000ooMo`06o`03gOl0008000?o`_l01_l01L;o
003o008^00So0?oo0?l^obP000?ogOl00ol0103ogOl40004onco00Co00?/o`000P001?l^o`02o`04
0?l^oaH000Co3ol00_l01@3o3`oo008000?oS_l01_l00hko00020003oaco00Ko00DLo`00o`023`08
o`3oo`3o3ol500000`02o`060?l00?l00ol@00?o00@0o`3o0P02o`800ol01P3o003o00;o6002o`06
0?l00?l00ol200;o0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_lX00;o00H0o`00
o`02o`@00_l01P3o003o00;o0`02o`060?l00?l00_lF00;o00H0o`00o`03o`800_l20004o`3o00?o
0`03o`040?l0o`800_l200?o00H0o`00o`02o`D000030003o`3o00@000Co003o40001?l00?l30004
o`00o`8000Co003o10000ol0o`0H0003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o
0`001?l00?l20004o`00o`@000?o0?l0:0001?l00?l30003o`3o00@000?o0?l00`001?l00?l30003
o`3o00@000?o0?l05P000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o
0P001?l00?l40003o`3o00D0003o01d0000300Co00<0o`001?l200Ko00<0ool00_l300Ko00<0ool0
0_lU00Co00<0o`001?l200Ko00<0ool00_l300Ko00<0ool00_lX00Go0P03o`<01?l00`3o0003o`@0
1Ol00`3oo`02o`<01?l00`3o0003oaH01?l00`3o0004o`801_l00`3oo`02oa001_l200?o1@0000<0
00Cobl_;0ol3b`04o`00o`?l00?oo?l00o`01Ol0003o00>>00?oS_l00hh00ol0000S0004oadM7@?o
0ad01?l00?l3`P03ol;o00?200Go0000o`03SP03ohko00>>00?o00009P001?l^;Rh3o`8^00Go0000
o`03`P?o0/800ol000020004ohj>SP?o0Xh01Ol0003o00>^0ol2[P03o`0001@000Co;Rh^0ol3;P04
o`00o`<L00?o7?l00a`00ol0000>0003ohj>00:>0ol2SP03o`0000<000030003ol_;00O;00Co003o
2O`01Ol0003o00V>00?o00008`000olM7@077@04o`00o`W200Go0000o`09SP03o`0002H000?o;Rh0
1Rh01Ol0003o00S200?o00000P000on>SP06SP05o`000?l02:h00ol0000D0003obh^00L^00Co003o
2A`00ol0000>0003ohj>00N>00?o00000`0000<000?obl/01l/01?l00?l9o005o`000?l02Hh00ol0
000S0003oadM00LM00Co003o2L801Ol0003o00V>00?o00009P000ol^;P06;P05o`000?l02<800ol0
00020003ohj>00J>00Go0000o`08[P03o`0001@000?o;Rh01bh01?l00?l97003o`0000h000?oSXh0
1hh00ol0000300000`000oo;b`04o`?;00Co003o0o`00oolo`03o005o`000?l00hh00on>o`03SP03
o`0002<000?o7Ad01?l37@04o`00o`?200?o`_l00l801Ol0003o00>>00?oS_l00hh00ol0000V0003
obh^00Co0Rh01Ol0003o00;21?l2`P03o`00008000?oSXh01?l2SP05o`000?l00Zh4o`:^00?o0000
50000ol^;P04o`<^00Co003o0a`00olLo`037003o`0000h000CoSXj>1?l2SP03o`0000<0000300_o
0P0;o`<02olU00_o0P0;o`<02olX00[o0`0:o`@02_l300[o5P0;o`802ol@00_o1@0000<000?o0?l0
10001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00obD000?o0?l010001?l00?l20004
o`00o`<000Co003o0`001?l00?l30004o`00obP000?o0?l010000ol0o`030004o`00o`<000?o0?l0
10000ol0o`030004o`00o`<000?o0?l010000ol0o`0F0003o`3o00@000Co003o0P001?l00?l30004
o`00oa0000Co003o10000ol0o`050000o`0M00000`02o`<000Co00000_l200;o0`001?l00002o`<0
0ol20004o`0000;o0P03o`8000?o00000P000ol0000F00;o0`001?l00002o`800_l30004o`0000;o
0`03o`8000Co00000_l200?o0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005
o`000?l01002o`8000?o00000P001?l00002o`<000Go0000o`0F00;o0`001?l00002oa000ol20004
o`0000;o4P0000<000?o3ol01_l01Poo003of`Oo00?Ko`000P000om]o`08o`8000?o3`l02?lH0003
o`oo00Ko00H?o`00oeh7o`03G_l0008000?oKOl02?l20003o`l?00So6`000ol^o`07o`<000?oG_l0
1ol40003oeko00Oo0`000ol?o`07oaH000?o7?l01_l00aco000?0003oaco00So4P0000<000?o3`l0
1`l01?l00?l9f`05o`000?l02Fd01?l00?l93`03o`0001H000?o3`l01`l01?l00?l9GP05o`000?l0
2Fd01?l00?l93`03o`0001T000?o;Rh01Rh01Ol0003o00QN00?o00000P000omNGP06GP05o`000?l0
20l00ol0000D0003oa`L00LL00?o00003P000olL70077003o`00010000030003o`l?00L?00Co003o
2M/01Ol0003o00U]00Co003o2@l00ol0000F0003o`l?00L?00Co003o2Eh01Ol0003o00U]00Co003o
2@l00ol0000I0003obh^00H^00Go0000o`08GP03o`00008000?oGUh01Uh01Ol0003o00P?00?o0000
50000olL70077003o`0000h000?o71`01a`00ol0000@00000`000ol?3`04o`<?00Co003o0m/00ooK
o`03f`05o`000?l00fd00om]o`03K@04o`00o`<?1?l23`03o`0001H000?o3`l01?l33`04o`00o`=N
00?oG_l00eh01Ol0003o00=]00?oKOl00fd01?l00?l33`Co0Pl00ol0000I0003obh^00Co0Rh01Ol0
003o009N1?l2GP03o`00008000?oGUh01?l2GP05o`000?l00Pl4o`8?00?o000050000olL7004o`<L
00?o00003P001olL71co7?l00a`00ol0000@00000`001?l?o`02o`050?l?3ol00P000ooKo`06o`03
fol0008000?oKOl01_l01Fgo003o008?00So0?oo0?l?oaP000Co3ol00_l01@3o3`oo008000?oG_l0
1_l00eko00020003ofgo00Ko00E]o`00o`023`08o`3oo`3o3olK0004obko00;o00@0obko0`000omN
o`03o`040?mNo`@000CoG_l01?l00eko00020004o`oo00;o00@0o`oo5P001?lLo`02o`050?lL7?l0
40000olLo`06o`037?l00140000300Co0P05o`800_l0103oo`05o`<01Ol0103oo`02o`801Ol200Co
6004o`801Ol200;o00@0ool01Ol300Go00@0ool00_l200Go0P04oa/01?l200Co0`02o`040?l000Co
1004o`8000Co0?oo0`04o`801?lF00Co0P05oa001Ol0103oo`02oa80003o01d0000@00;o0`001?l0
0002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol0000F00;o0`001?l00002o`800_l30004
o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0001T00_l20003o`00008000Co0000
0_l30005o`000?l04@02o`<000Go0000o`0F00;o0`001?l00002o`800_l30004o`0000;o0`03o`80
00Co00000_l200?o0P000ol000020003o`0000<0000@0003o`Go00?o00D0ool5o`030003o`Co00?o
00<0ool00_l20003oeiN00?o0P03oaP000OoW?oo0?l000;o00JLo`00ojh4o`050?oo[_l00`000om/
o`03o`030?oo00;o0P000omNGP03o`800olK0003oico00;o0P03o`<000Oo[_oo0?l000?o4@001omN
ool0o`000olF0007ojkoo`3o0002o`06[_l00?l?1?l01@3oo`oo00<000?oS_l00ol00`3oo`02o`80
00?oMWH00ol200?o1@00010000Oo1@D5o`Go00<500Go0000o`031003o`Co00<400Co003o15h3o`9N
00?o00005P001?nLW9`3o`>L00Co003o0jh00on^o`03[P05o`000?l00f`00om/o`03K004o`00o`AN
0ol2GP03o`0001T000CoW9bL0ol2W005o`000?l00jh3o`:^00?o00003`001?mNGUh3o`9N00?o0000
50001?n^[Zh3o`>^00Co003o0`l00ol?o`033`05o`000?l00hh00on>o`03SP04o`00o`Af0ol2MP03
o`0000<0000@0003o`D500L500Go0000o`091004o`00o`UN00?o00005P000onLW007W004o`00o`V^
00Go0000o`09K004o`00o`UN00?o00006@000onLW006W005o`000?l02:h00ol0000?0003oeiN00IN
00?o000050000on^[P07[P04o`00o`T?00Go0000o`09SP04o`00o`Uf00?o00000`00010000?o1@D0
1`D01Ol0003o00T400Co003o2Eh00ol0000F0003oibL00NL00Co003o2Jh01Ol0003o00U/00Co003o
2Eh00ol0000I0003oibL00JL00Go0000o`08[P03o`0000l000?oGUh01Uh00ol0000D0003ojj^00N^
00Co003o2@l01Ol0003o00V>00Co003o2GH00ol00003000040000ol5o`06o`031Ol0008000?o1?l0
1_l01@Co003o009N1_l00eko000G0003oico00Go0Y`01Ol00?n^00Oo00>^o`000P000om/o`06o`05
K?l00?l00Uh6o`03G_l001X000?oW?l01Ol00ico00020003ojko00Go00>^o`0040000omNo`05o`03
G_l001D000?o[_l01Ol2[P05o`00o`l01ol00`oo00020003ohko00Ko00F>o`00o`02MPKo00=fo`00
100001000_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02oaP00_l01P3o003o00?o
0P02o`8000Co0?l00ol300?o00@0o`3o0P02o`800ol01P3o003o00;o6`02o`060?l00?l00_l300;o
00H0o`00o`02oa400_l01P3o003o00;o5P02o`060?l00?l00ol200;o0P001?l0o`03o`<00ol0103o
0?l200;o0P03o`060?l00?l00_l5000040001?l00?l30004o`00o`<000Co003o0`001?l00?l20004
o`00o`@000?o0?l060000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o
0P001?l00?l40003o`3o01/000?o0?l010000ol0o`030004o`00o`<000?o0?l04@000ol0o`040003
o`3o01H000?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o
10000ol0o`050000o`0M00000`04o`030?l000Co0P06o`030?oo00;o0`06o`030?oo00;o0P06o`80
0olH00Co00<0o`001?l@00Ko00<0ool00_l200Ko0P03oa/01Ol200?o4@05o`030?oo00;o0`04o`03
0?l000?o5P04o`030?l000Co0P06o`030?oo00;o0`06o`030?oo00;o0P06o`800ol500000`001?l[
:b/3o`<[00Co003o0e/00omKo`03F`05o`000?l00f`00om/o`03K004o`00o`CN0ol2gP03o`0001H0
00CoJVYZ0ol3JP03o`0000h000OoK6a/ofco00=/00Co003o1=h3o`;N00?o00006@001?olo?`3o`;l
00?o00003`001?o/k>`3o`;/00Go0000o`03gP?o0]h00ol0000D0004ohj>SP?o0hh01?l00?l33`03
o`oo00<?00Go0000o`03cP03olko00?>00Co003o1=h3o`;N00?o00000`0000<000?o:b/01b/01?l0
0?l9F`05o`000?l02F`01?l00?l9gP03o`0001H000?oJVX01fX00ol0000>0003ofa/00M/00Co003o
2Mh00ol0000I0003oocl00Kl00?o00003`000oo/k006k005o`000?l02=h00ol0000D0003ohj>00N>
00Co003o2@l01Ol0003o00W>00Co003o2Mh00ol0000300000`000ol[:`07:`04o`00o`UK00Go0000
o`09K004o`00o`WN00?o00005P000omZJP07JP03o`0000h000?oK6`01f`01?l00?l9gP03o`0001T0
00?oo?`01_`00ol0000?0003onc/00K/00Go0000o`08gP03o`0001@000?oSXh01hh01?l00?l93`05
o`000?l02Lh01?l00?l9gP03o`0000<000030003ob/[00Co0b/01?l00?l3F`03oe_o00=K00Go0000
o`03K003ofco00=/00Co003o0mh4o`;N00?o00005P000omZJP04o`=Z00?o00003P001om/K6coK?l0
0f`01?l00?l3gPCo0]h00ol0000I0003oocl00Co0_`00ol0000?0003onc/00Co0^`01Ol0003o00;N
1?l2gP03o`0001@000?oSXh01?l3SP04o`00o`<?00?o3ol00`l01Ol0003o00?>00?oc_l00lh01?l0
0?l3gPCo0]h00ol0000300000`0;o`802ol300_o0P0;oaP02ol@00_o0P0;oa/02_lA00[o0`0:oaH0
2ol200_o0`0;o`802ol500000`000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<0
00Co003o0P001?l00?l40003o`3o01P000?o0?l010001?l00?l@0004o`00o`<000Co003o0P001?l0
0?l40003o`3o01/000?o0?l010000ol0o`0A0003o`3o00<000Co003o0`000ol0o`040003o`3o01H0
00?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0
o`050000o`0M00000`02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`80
00?o00000P000ol0000a00?o0P001?l00002obP00_l20003o`00008000Co00000_l30005o`000?l0
1002o`8000?o00000P000ol0000^00;o0`001?l00002o`<00ol20004o`0000;o4P0000<000Oo7?oo
0?l000;o00HLo`00ojd4o`050?oo[Ol00`000ooLo`03o`030?oo00;o0P000omQH@03o`800olc0003
ol;o00?o00<0ool00_lX0003o`Ko00;o0P03o`<000Oo3ooo0?l000?o10000ol^o`02o`030?oo00;o
<0000ol?o`03o`050?oo3ol00`000omLo`03o`030?oo00;o4P0000<000Co71`L0ol37004o`00o`>]
00?o[Ol00jd01Ol0003o00?L00?og?l00m`01?l00?l4H@?o0V400ol0000a0007ol;2`_o2o`03`P03
o`0002H000Co1PH60ol21P05o`000?l00`l3o`8?00?o00000P001?l^;Rh3o`8^00?o0000;P001ol?
3`oo3ol00`l01Ol0003o00=L00?oG?l00e`00ol0000@00000`000olL70077004o`00o`V]00Go0000
o`09g004o`00o`UQ00?o0000<@000oo2`P07`P03o`0002H000?o1PH01PH01Ol0003o00P?00?o0000
0P000ol^;P06;P03o`0002h000?o3`l01`l01Ol0003o00UL00?o0000400000<000?o71`01?l37004
o`00o`>]00?o[Ol00jd01Ol0003o00?L00?og?l00m`01?l00?l3H@Co0V400ol0000a0007ol;2`_o2
o`03`P03o`0002H000?o1PH01?l21P05o`000?l00Pl4o`8?00?o00000P000ol^;P04o`8^00?o0000
;P001ol?3`oo3ol00`l01Ol0003o00=L00?oG?l00e`00ol0000@00000`001?lLo`02o`050?lL7?l0
0P000on]o`06o`03[Ol0008000?og?l01_l01Mco003o009Q00So0?oo0?mQoc<000?o`_l01_l00l;o
000W0004o`Ko00;o00@0o`Ko0`000ol?o`03o`040?l?o`@000Co;_l01?l00bko000_0003o`oo00Ko
00<?o`000P000omLo`06o`03G?l00140000300Co0P05o`800_l0103oo`05o`<01Ol0103oo`02o`80
1Ol200Co<`05o`040?oo00;o:004o`801?l300;o00@0o`001?l400Co0P001?l0ool`00;o00@0ool0
1Ol300Go00@0ool00_lB0000o`0M0000o`0M00004006o`030?oo00;o4006o`800olH00Co00<0o`00
1?l200Ko00<0ool00_l300Ko00<0ool00_l200Ko0P03oa/01Ol200?o0`04o`030?l000?o1005o`03
0?oo00;o0`04o`030?l000?o5P04o`030?l000Co4006o`030?oo00;o0P06o`800ol5000040001oo]
kNgokOl00nd00ol0000>0003oc/k008k0ol2>`03o`0001H02ol20007omcLg?oLo`03g005o`000?l0
0`l00ol?o`033`04o`00o`@60ol21P03o`0001T000Co[Zj^0ol2[P05o`000?l00jh3o`:^00?o0000
0P001?l?3`l3o`8?00Go0000o`037@?o0Qd00ol0000D0004ooclo0?o0o`00ol0000>0007o`l?3ol?
o`033`04o`00o`@W0ol29`03o`0000<0000@0003ong]00O]00?o00003P000olk>`07>`03o`0001H0
2ol20003omcL00OL00Go0000o`093`04o`00o`T600?o00006@000on^[P06[P05o`000?l02:h00ol0
00020003o`l?00H?00Go0000o`087@03o`0001@000?oo?`01o`00ol0000>0003o`l?00L?00Co003o
2BL00ol00003000040000oo]k@07k@03o`0000h000?o>c/01c/00ol0000F00_o0P000ooLg007g005
o`000?l02@l01?l00?l91P03o`0001T000?o[Zh01Zh01Ol0003o00R^00?o00000P000ol?3`063`05
o`000?l021d00ol0000D0003oocl00Ol00?o00003P000ol?3`073`04o`00o`TW00?o00000`000100
00?okOl01_l00ngo000?0003oc/k00Ko00<ko`005`0;o`8000?og?l01_l00mco00020003o`oo00Ko
00D?o`00o`021PKo00<6o`006P000on^o`05o`03[_l0008000?o[_l01Ol00jko00030003o`oo00Go
00<?o`000P000olMo`05o`037Ol001D000?oo?l01Ol2o003o`0000h000?o3ol01_l01@oo003o008W
1_l00bOo000400004002o`8000Co0?l00ol@00?o00H0o`00o`02oaP00_l01P3o003o00?o0P02o`80
00Co0?l00ol300?o00@0o`3o0P02o`800ol01P3o003o00;o6`02o`060?l00?l00_l300;o00H0o`00
o`02o`@00_l01P3o003o00;o0`02o`060?l00?l00_lF00;o00H0o`00o`03oa000ol0103o0?l200;o
0P03o`060?l00?l00_l5000040001?l00?l30004o`00oa0000Co003o10000ol0o`0H0003o`3o00@0
00Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l06`000ol0
o`040003o`3o00<000Co003o0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o01H0
00?o0?l010001?l00?l@0004o`00o`<000Co003o0P001?l00?l40003o`3o00D0003o01d0000300;o
0`001?l00002o`800_l30004o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0001H0
0_l30004o`0000;o0P02o`<000Co00000_lf00;o0P000ol000020004o`0000;o0`001Ol0003o0340
0_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o0000
0`0000<000?oC?l01_l01Tco003o1@Oo00<5o`000P000onXo`08o`8000?okNd02?lH0003ofko00Ko
00I^o`00oid7o`03WOl003D000?o1_l01ol30003ojko00Oo<@000on^o`06o`06[_l00?n^1ol00jko
00020003ojko00So0P000on>SP08o`D000030003oda<00M<00Co003o2@D01Ol0003o00VX00Co003o
2Nd00ol0000F0003ofi^00M^00Co003o2Id00ol0000d0003o`H600H600Go0000o`08[P03o`0002l0
00?o[Zh01jh01?l00?l9[P05o`000?l02Jh01?l00?l9SP03o`0000<000030003oda<00M<00Co003o
2@D01Ol0003o00VX00Co003o2Nd00ol0000F0003ofi^00M^00Co003o2Id00ol0000d0003o`H600H6
00Go0000o`08[P03o`0002l000?o[Zh01jh01?l00?l9[P05o`000?l02Jh01?l00?l9SP03o`0000<0
00030003oda<00Co0d`01?l00?l31@03o`Go00<500Go0000o`03Z003ojSo00>X00Co003o0nd4o`;]
00?o00005P000om^KP04o`=^00Co003o0id00onMo`03W@03o`0003@000?o1PH01?l21P05o`000?l0
0Zh4o`:^00?o0000;`000on^[P04o`>^00Co003o0jh00on^o`03[P05o`000?l00jh00on^o`03[P04
o`00o`>>1?l2SP03o`0000<000030004odco00;o00D0oda<o`020003o`Go00Ko00<5o`000P000onX
o`06o`05Z?l00?l00^d02?l0ool0ongo60001?m^o`02o`050?m^K_l00P000onMo`06o`03WOl003D0
00Co1_l00_l0103o1_l30003ojko00?o00@0ojko<@001?n^o`02o`050?n^[_l00P000on^o`06o`03
[_l0008000?o[_l01_l01Jko003o00:>00So0?oo0?n>o`D0000300Co0P05o`800_l0103oo`05o`<0
1Ol0103oo`02o`801Ol200Co6004o`801Ol200;o00@0ool01Olf00Co0P04o`<00_l0103o0004oc40
1?l200Go0P02o`040?oo00Go0`05o`040?oo00;o0P05o`801?l50000o`0M0000o`0M00007P03o`80
00Co00000_l200?o0P000ol000020003o`0001H00_l30004o`0000;o4003o`8000Co00000_l200?o
0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005o`000?l01002o`8000?o0000
0P001?l00002o`<000Go0000o`0F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co0000
0_l200?o0P000ol000020003o`0000<0000N0003odco00So0P000ooMg@08oaP000?oc_l01_l00lko
000?0003obko00So0P000ooMg@08oa/000?o1_l01ol30003ojko00Oo10000ol^o`07o`<000?o1_l0
1olF0003o`oo00Ko00H?o`00ojh7o`03[_l0008000?o7?l02?l20003o`l?00So1@0001h000?oC4`0
1d`01?l00?l9g@03o`0001H000?oc/h01lh00ol0000>0003obh^00L^00Co003o2Md00ol0000I0003
o`H600H600Go0000o`08[P03o`00008000?o;Rh01Rh01Ol0003o00P600?o000050000ol?3`073`04
o`00o`V^00Go0000o`097004o`00o`T?00?o00000`0001h000?oC4`01d`01?l00?l9g@03o`0001H0
00?oc/h01lh00ol0000>0003obh^00L^00Co003o2Md00ol0000I0003o`H600H600Go0000o`08[P03
o`00008000?o;Rh01Rh01Ol0003o00P600?o000050000ol?3`073`04o`00o`V^00Go0000o`097004
o`00o`T?00?o00000`0001h000?oC?l01_l01Dco003o00;M1_l00mgo000G0003olko00Go0/h00ol0
000>0003obko00Ko00D^o`00o`02g@Ko00?Mo`006P000ol6o`05o`031_l0008000?o[_l01Ol00jko
00030003obko00Go00<^o`000P000ol6o`05o`031_l001D000?o3ol01Ol23`05o`00ojh01ol00jko
00020003oaco00Ko00DLo`00o`023`Ko00<?o`00100001h00ol0103o0?l200;o0P03o`060?l00?l0
0_lH00;o00H0o`00o`03oa000ol0103o0?l200;o0P03o`060?l00?l00_lK00;o00H0o`00o`02o`<0
0_l01P3o003o00;o1002o`060?l00?l00_l300;o00H0o`00o`02oaH00_l01P3o003o00?o0P02o`80
00Co0?l00ol300?o00@0o`3o0P02o`800ol01P3o003o00;o1@0001h000Co003o0`001?l00?l20004
o`00o`@000?o0?l060000ol0o`040004o`00oa0000Co003o0`001?l00?l20004o`00o`@000?o0?l0
6`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003
o`3o01H000?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o
10000ol0o`050000o`0M00000`02o`<000Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o
0P03o`8000?o00000P000ol0000F00;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co0000
0_l200?o0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005o`000?l01002o`80
00?o00000P000ol0000^00;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol0
000300000`001omNool0o`000_l01Uko003o10Co00D0ool4o`030003ol;o00?o00<0ool00_l20003
olc<00?o0P03oaP000Oo;Ooo0?l000;o00H]o`00obd4o`050?oo;Ol00`000om]o`03o`030?oo00;o
0P000oo/k003o`800olK0003obgo00;o0P03o`<000Oo;_oo0?l000?o10000onYo`02o`030?oo00;o
<0000on^o`03o`050?oo[_l00`000olWo`03o`030?oo00;o0P000ol?3`03o`800ol500000`001?mN
GUh3o`=N00Co003o0`@00ol4o`031005o`000?l00l800oo2o`03`P04o`00o`C<0ol2c003o`0001H0
00Co;Bd]0ol3;@04o`00o`<]00?o;Ol00bd01Ol0003o00=]00?oKOl00fd01?l00?l4k0?o0^`00ol0
000I0004obd];@?o0Rd01Ol0003o00<^0ol2;P03o`00008000CoZJVY0ol2Z@03o`0002h000Oo[Zj^
ojko00>^00Go0000o`039`03obOo00<W00Co003o10l3o`8?00?o00000`0000<000?oGUh01eh01?l0
0?l91005o`000?l02L801?l00?l9c003o`0001H000?o;Bd01bd01?l00?l9;@05o`000?l02Fd01?l0
0?l9k003o`0001T000?o;Bd01Rd01Ol0003o00P^00?o00000P000onYZ@06Z@03o`0002h000?o[Zh0
1jh01Ol0003o00TW00Co003o2@l00ol0000300000`000omNGP07GP04o`00o`T400Go0000o`09`P04
o`00o`W<00?o00005P000ol];@07;@04o`00o`T]00Go0000o`09K@04o`00o`W/00?o00006@000ol]
;@06;@05o`000?l022h00ol000020003ojVY00JY00?o0000;P000on^[P07[P05o`000?l02BL01?l0
0?l93`03o`0000<000030003oeko00Go0Uh01Ol00?l400Oo00<4o`000P000oo2o`06o`05`_l00?l0
0/`6o`03c?l001L000?o;Ol01Ol2;@05o`00obd01ol00bgo00020003ofgo00Ko00E]o`00o`02k0Ko
00?/o`006P000ol]o`05o`03;Ol0008000?o;_l01Ol00bko00030003ojWo00Go00>Yo`00;`000on^
o`06o`03[_l0008000?o9ol01_l01BOo003o008?1_l00`oo000400000`02o`060?l00?l00ol200;o
0P001?l0o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_lH00;o00H0o`00o`03o`800_l20004
o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02oa/00_l01P3o003o00;o0`02o`060?l00?l0
0_l400;o00H0o`00o`02oc000_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02o`D0
00030003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@0
00?o0?l060000ol0o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o0P001?l0
0?l40003o`3o01/000?o0?l010000ol0o`030004o`00o`<000?o0?l010000ol0o`030004o`00oc00
00Co003o0`001?l00?l30004o`00o`<000Co003o0P001?l00?l40003o`3o00D0003o01d0000300;o
0`001?l00002o`800_l30004o`0000;o0`03o`8000Co00000_lU00;o0`001?l00002o`800_l30004
o`0000;o=P02o`8000?o00000P001?l00002o`<000Go0000o`0400;o0P000ol000020003o`0002h0
0_l30004o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0000<000030003ohgo00Ko
00J=o`00ojd7o`03[Ol0008000?obol02?lU0003omco00Ko00KLo`00ofh7o`03K_l003D000?oc_l0
1ol30003obko00Oo10000on^o`07oc0000?oS_l01_l00hko00020003o`oo00So0P000on^[P08o`D0
00030003ohf=00N=00Co003o2Jd01Ol0003o00W;00?o00008`000ooLg007g004o`00o`U^00?o0000
=0000oo>cP06cP05o`000?l022h00ol000020003ojj^00J^00?o0000;P000on>SP07SP05o`000?l0
2@l01?l00?l9[P03o`0000<000030003ohf=00N=00Co003o2Jd01Ol0003o00W;00?o00008`000ooL
g007g004o`00o`U^00?o0000=0000oo>cP06cP05o`000?l022h00ol000020003ojj^00J^00?o0000
;P000on>SP07SP05o`000?l02@l01?l00?l9[P03o`0000<000030003ohf=00Co0hd01?l00?l3[@03
ojgo00>]00Go0000o`03b`03ol_o00?;00?o00008`000ooLg004o`?L00Co003o0fh00om^o`03KP03
o`0003@000?oc/h01?l2cP05o`000?l00Rh4o`8^00?o00000P000on^[P04o`:^00?o0000;P001on>
SXkoS_l00hh01Ol0003o00<?00?o3ol00`l01?l00?l3[PCo0Zh00ol0000300000`0;o`802ol300_o
9@0;o`802olf00[o0`0:o`@02_l`00_o0`0;o`802ol500000`000ol0o`040004o`00o`8000Co003o
0`001?l00?l30004o`00o`<000Co003o9@000ol0o`040004o`00o`8000Co003o0`001?l00?lf0003
o`3o00@000?o0?l00`001?l00?l30003o`3o00@000?o0?l00`001?l00?l`0004o`00o`<000Co003o
0`001?l00?l30004o`00o`8000Co003o10000ol0o`050000o`0M00000`02o`<000Co00000_l@00?o
0P001?l00002o`800ol20003o`00008000?o00005P02o`<000Co00000_l200;o0`001?l00002oa00
0ol20003o`00008000?o00006@02o`8000?o00000P001?l00002o`<000Go0000o`0400;o0P000ol0
00020004o`0000;o0`001Ol0003o01H00_l30004o`0000;o0P02o`<000Co00000_l300?o0P001?l0
0002o`800ol20003o`00008000?o00000`0000<000OoZooo0?l000;o00>[o`003`000ol^o`03o`03
0?oo00;o0P000ol?3`03o`800olH0007ojkoo`3o0002o`06[_l00?o>1?l01@3oolko010000?o3`l0
0ol200?o6`000ol?o`02o`800ol30007o`ooo`3o0003o`@000?o;Ol00_l00`3oo`02o`<000Oo3ooo
0?l000?o5P001oo>ool0o`000_l01/ko003ocPCo00D0ooo>o`030003o`oo00?o00<0ool00_l20003
o`l?00?o0P03o`D000030004oj^[Z`?o0j/00ol0000>0007obh^;_l^o`03;P04o`00o`@?0ol23`03
o`0001H000Co[Zj^0ol3[P04o`00o`?>00?oc_l00lh00ol0000>0003o`l?008?0ol23`03o`0001T0
00Co3`l?0ol23`05o`000?l00`l3o`8?00?o00000P001?l];Bd3o`8]00Go0000o`033`?o0Pl00ol0
000D0004olk>cP?o0lh01?l00?l3cP03olko00?>00Go0000o`033`03o`oo00<?00Co003o10l3o`8?
00?o00000`0000<000?oZj/01j/00ol0000>0003obh^00L^00Co003o2@l00ol0000F0003ojj^00N^
00Co003o2Lh00ol0000>0003o`l?00L?00?o00006@000ol?3`063`05o`000?l020l00ol000020003
obd]00H]00Go0000o`083`03o`0001@000?oc/h01lh01?l00?l9cP05o`000?l02@l01?l00?l93`03
o`0000<000030003oj^[00Co0j/00ol0000>0007obh^;_l^o`03;P04o`00o`<?1?l23`03o`0001H0
00?o[Zh01?l3[P04o`00o`?>00?oc_l00lh00ol0000>0004o`l?3`Co0Pl00ol0000I0003o`l?00Co
0Pl01Ol0003o008?1?l23`03o`00008000?o;Bd01?l2;@05o`000?l00Pl4o`8?00?o000050000oo>
cP04o`?>00Co003o0lh00oo>o`03cP05o`000?l00`l00ol?o`033`04o`00o`<?1?l23`03o`0000<0
00030004oj_o00;o00D0oj^[o`0@0003obko00Ko00D^o`00o`023`08o`3oo`3o3olH0004ojko00;o
00D0ojj^o`020003olko00Ko00?>o`003`001Ol?3ol000;o00@0o`oo6`001?l?o`02o`040?l?o`<0
00?o3ol00ol0103o3ol40004obgo00Co00<]o`000P001?l?o`02o`040?l?oaH000Coc_l00_l01@3o
c/ko008000?oc_l01_l00lko00020003o`oo00Ko00D?o`00o`023`08o`3oo`3o3ol500000`02o`06
0?l00?l00ol@00?o00@0o`3o0P02o`800ol01P3o003o00;o6002o`060?l00?l00ol200;o0P001?l0
o`03oa000ol01P3o003o00;o6`02o`060?l00?l00_l300;o00H0o`00o`02o`@00_l01P3o003o00;o
0`02o`060?l00?l00_lF00;o00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_l200?o
00H0o`00o`02o`D000030003o`3o00@000Co003o40001?l00?l30004o`00o`8000Co003o10000ol0
o`0H0003o`3o00@000Co003o0P001?l00?l30004o`00oa0000Co003o10000ol0o`0K0003o`3o00@0
00?o0?l00`001?l00?l30003o`3o00@000?o0?l00`001?l00?l30003o`3o00@000?o0?l05P000ol0
o`040004o`00o`8000Co003o0`001?l00?l30004o`00o`<000Co003o0P001?l00?l40003o`3o00D0
003o01d0000300Co00<0o`001?l200Ko00<0ool00_l@00Ko0P03oaP01?l00`3o0004o`801_l00`3o
o`02o`<01_l00`3oo`02o`801_l200?o6`05o`800ol300Co00<0o`000ol400Go00<0ool00_lS00Co
00<0o`001?l200Ko00<0ool00_l300Ko00<0ool00_lB00000`001?nLW9`3o`>L00Co003o0a`00olL
o`037003o`0000h000?oWYh00Yh3o`:N00?o00005P001?nLW9`3o`>L00Co003o0dh00om>o`03CP05
o`000?l00ih00onNo`03WP04o`00o`@60ol21P03o`0001T000Cok>c/0ol2k005o`000?l00jh3o`:^
00?o00000P001?nNWYh3o`:N00?o00008@001?o>c/h3o`?>00Co003o0jh00on^o`03[P05o`000?l0
0`l00ol?o`033`03o`00010000030003oibL00NL00Co003o2A`00ol0000>0003oijN00NN00?o0000
5P000onLW007W004o`00o`U>00Go0000o`09WP04o`00o`T600?o00006@000oo/k006k005o`000?l0
2:h00ol000020003oijN00JN00?o00008@000oo>cP07cP04o`00o`V^00Go0000o`093`03o`000100
00030003oibL00NL00Co003o2A`00ol0000>0003oijN00NN00?o00005P000onLW007W004o`00o`U>
00Go0000o`09WP04o`00o`T600?o00006@000oo/k006k005o`000?l02:h00ol000020003oijN00JN
00?o00008@000oo>cP07cP04o`00o`V^00Go0000o`093`03o`00010000030003oibL00Co0i`01?l0
0?l37003oaco00<L00?o00003P001?nNWYh4o`:N00?o00005P000onLW004o`>L00Co003o0dh00om>
o`03CP05o`000?l00ih00onNo`03WP04o`00o`<61?l21P03o`0001T000?ok>`01?l2k005o`000?l0
0Zh4o`:^00?o00000P000onNWP04o`:N00?o00008@000oo>cP04o`?>00Co003o0jh00on^o`03[P05
o`000?l00`l00ol?o`033`03o`000100000300_o0P0;oa002olH00_o0P0;o`<02ol200_o6`0:o`<0
2_l400[o8`0;o`802ol300_o4P0000<000?o0?l010001?l00?l20004o`00o`<000Co003o40001?l0
0?l40003o`3o01P000?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`80
00Co003o10000ol0o`0K0003o`3o00@000?o0?l00`001?l00?l30003o`3o00@000?o0?l00`001?l0
0?lS0003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l00?lB0000o`0M0000
0`02o`<000Co00000_m000;o0`001?l00002o`800_l30004o`0000;o4003o`8000?o00000P000ol0
000I00;o0P000ol000020004o`0000;o0`001Ol0003o00@00_l20003o`00008000Co00000_l30005
o`000?l08`02o`<000Co00000_l@00?o0P000ol000020003o`0000<000030003obco00Ko00</o`00
?`0;o`8000?o3ol01_l00`oo000?0003onk^00So6`000ol?o`07o`<000?o3ol01ol40003o`oo00Oo
0`000oo>o`07ob<000?o3ol01_l00`oo000?0003o`l?00So1@0000<000?o;2`01b`00ol0000n00_o
0P000ol?3`073`03o`0000h000?ok^h01nh00ol0000I0003o`l?00H?00Go0000o`083`03o`000080
00?o3`l01Pl01Ol0003o00S>00?o00008@000ol?3`073`03o`0000h000?o3`l01`l00ol000030000
0`000ol/;007;003o`0003h02ol20003o`l?00L?00?o00003P000oo^kP07kP03o`0001T000?o3`l0
1Pl01Ol0003o00P?00?o00000P000ol?3`063`05o`000?l02<h00ol0000Q0003o`l?00L?00?o0000
3P000ol?3`073`03o`0000<000030003ob`/00Co0b`00ol0000n00_o0P001ol?3`oo3ol00`l00ol0
000>0004onk^kPCo0^h00ol0000I0003o`l?00Co0Pl01Ol0003o008?1?l23`03o`00008000?o3`l0
1?l23`05o`000?l00/h4o`;>00?o00008@001ol?3`oo3ol00`l00ol0000>0004o`l?3`Co0Pl00ol0
000300000`001?l/o`02o`050?l/;?l0@003o`040?oo00Co0P000ol?o`06o`033ol000l000Gok^ko
0002o`040?o^oa/000Co3ol00_l0103o3ol30003o`oo00?o00@0o`oo10001?l?o`04o`033ol00080
00Coc_l00_l0103oc_lS0003o`oo00Ko00<?o`003`001Ol?3ol000;o00@0o`oo1@0000<01?l200Go
@004o`801Ol200;o00@0ool01Ol@00Go0P04oa/01?l200Co0`02o`040?l000Co1004o`8000Co0?oo
0`04o`801?lS00;o00@0ool01Ol@00Go0P04o`D0003o01d0000300;o0`001?l00002oa000ol20004
o`0000;o0P03o`8000?o00000P000ol0000F00;o0`001?l00002o`800_l30004o`0000;o0`03o`80
00Co00000_l200?o0P000ol000020003o`0001T00_l20003o`00008000Co00000_l30005o`000?l0
1002o`8000?o00000P000ol0000Q00;o0`001?l00002o`800_l30004o`0000;o4003o`8000?o0000
0P000ol0000300000`001oo>ool0o`000_l00lko000?0003ojko00?o00<0ool00_l20003onc/00?o
0P03oaP000Ooc_oo0?l000;o00K>o`00ofd4o`050?ooKOl00`000on^o`03o`030?oo00;o0P000oo/
k003o`800olK0003olko00;o0P03o`<000OoKOoo0?l000?o10000on^o`02o`030?oo00;o8`001ol?
ool0o`000_l01Poo003o3`Co00D0ool?o`0@0003olk>00?o0P03o`D000030004olk>cP?o0lh00ol0
000>0007ojj^[_n^o`03[P04o`00o`C/0ol2k003o`0001H000Coc/k>0ol3cP04o`00o`=]00?oKOl0
0fd01Ol0003o00>^00?o[_l00jh01?l00?l4k0?o0^`00ol0000I0004olk>cP?o0/h01Ol0003o00=]
0ol2K@03o`00008000Co[Zj^0ol2[P03o`00024000Co3`l?0ol33`04o`00o`<?00?o3ol00`l00ol0
000>0003olk>00;>0ol2cP03o`0000<000030003olk>00O>00?o00003P000on^[P07[P04o`00o`W/
00?o00005P000oo>cP07cP04o`00o`U]00Go0000o`09[P04o`00o`W/00?o00006@000oo>cP06cP05
o`000?l026d00ol000020003ojj^00J^00?o00008@000ol?3`073`04o`00o`T?00?o00003P000oo>
cP07cP03o`0000<000030003olk>00O>00?o00003P000on^[P07[P04o`00o`W/00?o00005P000oo>
cP07cP04o`00o`U]00Go0000o`09[P04o`00o`W/00?o00006@000oo>cP06cP05o`000?l026d00ol0
00020003ojj^00J^00?o00008@000ol?3`073`04o`00o`T?00?o00003P000oo>cP07cP03o`0000<0
00030003olko00Go0/h00ol0000>0003ojko00Ko00F^o`00o`02k0Ko00?/o`005`000oo>o`05o`;>
00Go003oK@07o`03KOl0008000?o[_l01_l01Jko003o00;/1_l00nco000J0003olko00Go00?>o`00
0P000om]o`05o`03KOl000<000?o[_l01Ol00jko000R0003o`oo00Go0Pl01Ol00?l?00Oo00<?o`00
3`000oo>cP06o`03c_l000@0000300;o00H0o`00o`03oa000ol0103o0?l200;o0P03o`060?l00?l0
0_lH00;o00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02oa/0
0_l01P3o003o00;o0`02o`060?l00?l00_l400;o00H0o`00o`02ob<00_l01P3o003o00?o0P02o`80
00Co0?l00ol@00?o00H0o`00o`02o`D000030003o`3o00@000Co003o40001?l00?l30004o`00o`80
00Co003o10000ol0o`0H0003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l0
0?l20004o`00o`@000?o0?l06`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o00<0
00Co003o8`000ol0o`040004o`00o`8000Co003o0`001?l00?l@0004o`00o`@000?o0?l01@000?l0
7@0001001_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o6004o`030?l000Co0P06o`030?oo00;o
0`06o`030?oo00;o0P06o`800olK00Go0P03o`<01?l00`3o0003o`@01Ol00`3oo`02o`<01?l00`3o
0003oaH01?l00`3o0004o`801_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o1@00010000OoWIfM
oigo00>M00Go0000o`031P03o`Ko00<600Co003o1<h3o`;>00?o00005P001?lM7Ad3o`<M00Co003o
0id00onMo`03W@05o`000?l00hh00on>o`03SP04o`00o`C>0ol2cP03o`0001T000Co[Zj^0ol2[P05
o`000?l00id3o`:M00?o00000P001?n>SXh3o`:>00Go0000o`037@?o0Qd00ol0000D0004ojj^[P?o
0jh01?l00?l31@03o`Go00<500Go0000o`033`03o`oo00<?00Co003o10l3o`8?00?o00000`000100
00?oWId01id01Ol0003o00T600Co003o2Lh00ol0000F0003oadM00LM00Co003o2Id01Ol0003o00V>
00Co003o2Lh00ol0000I0003ojj^00J^00Go0000o`08W@03o`00008000?oSXh01Xh01Ol0003o00PM
00?o000050000on^[P07[P04o`00o`T500Go0000o`093`04o`00o`T?00?o00000`00010000?oWId0
1id01Ol0003o00T600Co003o2Lh00ol0000F0003oadM00LM00Co003o2Id01Ol0003o00V>00Co003o
2Lh00ol0000I0003ojj^00J^00Go0000o`08W@03o`00008000?oSXh01Xh01Ol0003o00PM00?o0000
50000on^[P07[P04o`00o`T500Go0000o`093`04o`00o`T?00?o00000`00010000OoWIfMoigo00>M
00Go0000o`031P03o`Ko00<600Co003o0lh4o`;>00?o00005P000olM7@04o`<M00Co003o0id00onM
o`03W@05o`000?l00hh00on>o`03SP04o`00o`?>1?l2cP03o`0001T000?o[Zh01?l2[P05o`000?l0
0Yd4o`:M00?o00000P000on>SP04o`:>00Go0000o`027@Co0Qd00ol0000D0003ojj^00Co0jh01?l0
0?l31@03o`Go00<500Go0000o`033`03o`oo00<?00Co003o0`l4o`8?00?o00000`0001002ol300_o
0P0;oaP02ol200_o0`0;o`802olK00[o0`0:o`@02_l300[o5P0;o`802ol300_o0P0;o`D0000@0004
o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0o`0H0003o`3o00@000Co003o
0P001?l00?l30004o`00o`<000Co003o0`001?l00?l20004o`00o`@000?o0?l06`000ol0o`040003
o`3o00<000Co003o0`000ol0o`040003o`3o00<000Co003o0`000ol0o`040003o`3o01H000?o0?l0
10001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0o`050000
o`0M00000`02o`<000Co00000_l200;o0`001?l00002oa000ol20003o`00008000?o00005P02o`<0
00Co00000_l200;o0`001?l00002o`<00ol20004o`0000;o0P03o`8000?o00000P000ol0000I00;o
0P000ol000020004o`0000;o0`001Ol0003o00@00_l20003o`00008000Co00000_l30005o`000?l0
8`02o`<000Co00000_l300?o0P001?l00002o`800ol20003o`00008000?o00000`0000<000OoKOoo
0?l000;o00I]o`00obd4o`050?oo;Ol040000on^[P03o`800olH0007ofgoo`3o0002o`06KOl00?l]
1?l01@3oobgo00<000?ok?l00ol00`3oo`02o`8000?o[Zh00ol200?o6`000on^o`02o`800ol30007
o`ooo`3o0003o`@000?ok?l00_l00`3oo`02o`<000Oo[_oo0?l000?o8`000ol?o`03o`050?oo3ol0
0`000ol^o`03o`030?oo00;o0P000onNWP03o`800ol500000`001?m]KFd3o`=]00Co003o0bd00ol]
o`03;@03o`0000h000?o[Zh00Zh3o`:^00?o00005P001?m]KFd3o`=]00Co003o0bd00ol]o`03;@05
o`000?l00n`00oo/o`03k004o`00o`B^0ol2[P03o`0001T000Co[Zj^0ol2[P05o`000?l00`l3o`8?
00?o00000P001?o/k>`3o`;/00Go0000o`03[P?o0Zh00ol0000Q0007o`l?3ol?o`033`05o`000?l0
0bh00ol^o`03;P04o`00o`BN0ol2WP03o`0000<000030003ofe]00M]00Co003o2Bd00ol0000>0003
ojj^00N^00?o00005P000om]K@07K@04o`00o`T]00Go0000o`09k004o`00o`V^00?o00006@000on^
[P06[P05o`000?l020l00ol000020003onc/00K/00Go0000o`08[P03o`00024000?o3`l01`l01Ol0
003o00T^00Co003o2Ih00ol0000300000`000om]K@04o`=]00Co003o0bd00ol]o`03;@03o`0000h0
00Co[Zj^1?l2[P03o`0001H000?oKFd01?l3K@04o`00o`<]00?o;Ol00bd01Ol0003o00?/00?ok?l0
0n`01?l00?l3[PCo0Zh00ol0000I0003ojj^00Co0Zh01Ol0003o008?1?l23`03o`00008000?ok>`0
1?l2k005o`000?l00Zh4o`:^00?o00008@001ol?3`oo3ol00`l01Ol0003o00<^00?o;_l00bh01?l0
0?l3WPCo0Yh00ol0000300000`001?m]o`02o`050?m]KOl00P000ol]o`06o`03;Ol000l000Go[Zko
0002o`040?n^oaP000CoKOl00_l01@3oKFgo008000?o;Ol01_l00bgo00020003onco00Ko00G/o`00
o`02[P08o`3oo`3o[_lK0004ojko00;o00@0ojko0`000ol?o`03o`040?l?o`@000Cok?l01?l00nco
00020004ojko00;o00@0ojko8`000ol?o`06o`033ol0008000?o;_l01_l01Bko003o00:N00So0?oo
0?nNo`D0000300Co0P05o`800_l0103oo`05oa001Ol200Co6004o`801Ol200;o00@0ool01Ol300Go
00@0ool00_l200Go0P04oa/01?l200Co0`02o`040?l000Co1004o`8000Co0?oo0`04o`801?lS00;o
00@0ool01Ol300Go00@0ool00_l200Go0P04o`D0003o01d0003o01d0000300Co00<0o`001?l200Ko
00<0ool00_l300Ko00<0ool00_l200Ko0P03oaP01?l00`3o0004o`801_l00`3oo`02o`<01_l00`3o
o`02obP01Ol200?o0`04o`030?l000?o1005o`030?oo00;o8`04o`030?l000Co0P06o`030?oo00;o
4006o`800ol500000`001?l^;Rh3o`<^00Co003o0fX00omZo`03JP05o`000?l00`H00ol6o`031P04
o`00o`@M0ol27@03o`0001H000Co;Rh^0ol3;P04o`00o`>^00?o[_l00jh01Ol0003o00<600?o1_l0
0`H00ol0000V0004onc/k0?o0^`01Ol0003o00>^0ol2[P03o`00008000Co1PH60ol21P03o`000240
00Co3`l?0ol33`04o`00o`>^00?o[_l00jh00ol0000>0003o`l?008?0ol23`03o`0000<000030003
obh^00L^00Co003o2FX01Ol0003o00T600Co003o2Ad00ol0000F0003obh^00L^00Co003o2Jh01Ol0
003o00T600?o00009P000oo/k006k005o`000?l02:h00ol000020003o`H600H600?o00008@000ol?
3`073`04o`00o`V^00?o00003P000ol?3`073`03o`0000<000030003obh^00L^00Co003o2FX01Ol0
003o00T600Co003o2Ad00ol0000F0003obh^00L^00Co003o2Jh01Ol0003o00T600?o00009P000oo/
k006k005o`000?l02:h00ol000020003o`H600H600?o00008@000ol?3`073`04o`00o`V^00?o0000
3P000ol?3`073`03o`0000<000030003obko00Go0Rh01Ol00?mZ00Oo00=Zo`000P000ol6o`06o`05
1_l00?l00Qd6o`037Ol001L000?o;_l01Ol2;P05o`00ojh01ol00jko00020003o`Ko00Ko00<6o`00
9`000oo/o`05o`03k?l0008000?o[_l01Ol00jko00030003o`Ko00Go00<6o`008P000ol?o`05o`8?
00Go003o[P07o`03[_l000l000?o3`l01_l00`oo000400000`02o`060?l00?l00ol200;o0P001?l0
o`03o`<00ol0103o0?l200;o0P03o`060?l00?l00_lH00;o00H0o`00o`03o`800_l20004o`3o00?o
0`03o`040?l0o`800_lX00;o00H0o`00o`02o`<00_l01P3o003o00;o1002o`060?l00?l00_lS00;o
00H0o`00o`03o`800_l20004o`3o00?o4003o`060?l00?l00_l500000`000ol0o`040004o`00o`80
00Co003o0`001?l00?l30004o`00o`<000Co003o0P001?l00?l40003o`3o01P000?o0?l010001?l0
0?l20004o`00o`<000Co003o0`001?l00?l30004o`00obP000?o0?l010000ol0o`030004o`00o`<0
00?o0?l010000ol0o`030004o`00ob<000?o0?l010001?l00?l20004o`00o`<000Co003o40001?l0
0?l40003o`3o00D0003o01d0000300;o0`001?l00002o`800_l30004o`0000;o0`03o`8000Co0000
0_l200?o0P000ol000020003o`0001H00_l30004o`0000;o0P02o`<000Co00000_l@00?o0P000ol0
00020003o`0001T00_l20003o`00008000Co00000_l30005o`000?l01002o`8000?o00000P001?l0
0002o`<000Go0000o`0F00;o0`001?l00002oa000ol20004o`0000;o0P03o`8000?o00000P000ol0
000300000`000omKo`06o`06Fol00?nK1ol00i_o00020003o`Ko00So0P000omfMP08oaP000?oG_l0
1_l01Uko003o;POo00<^o`003`000on^[P08oa/000?oG_l01ol30003obko00Oo10000ol?o`07o`<0
00?o[_l01olF0003omko00Ko00?No`003`000ol4o`08o`8000?o3`l02?l500000`000omKF`07F`04
o`00o`VK00Go0000o`091P04o`00o`Uf00?o00005P000omNGP07GP04o`00o`T^00?o00003P000on^
[P07[P03o`0001T000?oGUh01Uh01Ol0003o00P^00?o00000P000ol?3`063`05o`000?l02:h00ol0
000D0003omkN00ON00?o00003P000ol410071004o`00o`T?00?o00000`0000<000?oFe/01e/01?l0
0?l9V`05o`000?l02@H01?l00?l9MP03o`0001H000?oGUh01eh01?l00?l9;P03o`0000h000?o[Zh0
1jh00ol0000I0003oeiN00IN00Go0000o`08;P03o`00008000?o3`l01Pl01Ol0003o00R^00?o0000
50000ooNgP07gP03o`0000h000?o10@01`@01?l00?l93`03o`0000<000030003oe]K00Co0e/01?l0
0?l3V`03oi_o00>K00Go0000o`031P03o`Ko00<600Co003o0gH4o`9f00?o00005P000omNGP04o`=N
00Co003o0bh00ol^o`03;P03o`0000h000Co[Zj^1?l2[P03o`0001T000?oGUh01?l2GP05o`000?l0
0Rh4o`8^00?o00000P000ol?3`04o`8?00Go0000o`02[PCo0Zh00ol0000D0003omkN00Co0mh00ol0
000>0007o`@41?l4o`031004o`00o`<?1?l23`03o`0000<000030004oe_o00;o00D0oe]Ko`020003
oi_o00Ko00>Ko`000P000ol6o`06o`051_l00?l00WH02?l0ool0ogKo60001?mNo`02o`050?mNG_l0
0P000ol^o`06o`03;_l000l000Go[Zko0002o`040?n^oa/000CoG_l00_l0103oG_l30003obko00?o
00@0obko10001?l?o`04o`033ol0008000Co[_l00_l0103o[_lF0004omko00;o00D0omkNo`0@0003
o`Co00Ko00D4o`00o`023`08o`3oo`3o3ol500000`04o`801Ol200;o00@0ool01Ol300Go00@0ool0
0_l200Go0P04oaP01?l200Go0P02o`040?oo00Go4005o`801?lK00Co0P04o`<00_l0103o0004o`@0
1?l20004o`3oo`<01?l200Co5P04o`801Ol@00Go00@0ool00_l200Go0P04o`D0003o01d0000300;o
0`001?l00002o`800_l30004o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0002<0
0_l30004o`0000;o0`03o`8000Co00000_l200?o0P000ol000020003o`0002H00_l30005o`000?l0
1002o`8000?o00000P001?l00002o`<000Go0000o`0F00;o0`001?l00002o`800_l30004o`0000;o
0`03o`8000Co00000_l200?o0P000ol000020003o`0000<000030007ol_oo`3o0002o`06bol00?lW
1?l01@3oobOo00<000?oc_l00ol00`3oo`02o`8000?okNd00ol200?o9@000olWo`03o`050?oo9ol0
0`000oo>o`03o`030?oo00;o0P000oo]k@03o`800olX0007obOoo`3o0003o`@000?oc_l00_l00`3o
o`02o`<000Oo3ooo0?l000?o5P001omLool0o`000_l01Uco003o9`Co00D0oolWo`030003omko00?o
00<0ool00_l20003o`l?00?o0P03o`D000030004ol_;b`?o0l/01?l00?l39`03obOo00<W00Go0000
o`03cP03olko00?>00Co003o1>d3o`;]00?o00008`001olW9bOo9ol00bL01Ol0003o00?>00?oc_l0
0lh01?l00?l4k@?o0^d00ol0000V0004obLW9`?o0RL00ol000020004olk>cP?o0/h01Ol0003o00<?
0ol23`03o`0001@000CoG5aL0ol3G004o`00o`<W00?o9ol00bL01Ol0003o00?N00?og_l00mh01?l0
0?l43`?o0Pl00ol0000300000`000oo;b`07b`04o`00o`TW00Go0000o`09cP04o`00o`W]00?o0000
8`000olW9`079`05o`000?l02Lh01?l00?l9k@03o`0002H000?o9bL01RL00ol000020003olk>00K>
00Go0000o`083`03o`0001@000?oG5`01e`01?l00?l99`05o`000?l02Mh01?l00?l93`03o`0000<0
00030003ol_;00O;00Co003o2BL01Ol0003o00W>00Co003o2Nd00ol0000S0003obLW00LW00Go0000
o`09cP04o`00o`W]00?o00009P000olW9`069`03o`00008000?oc/h01/h01Ol0003o00P?00?o0000
50000omLG007G004o`00o`TW00Go0000o`09gP04o`00o`T?00?o00000`0000<000?obol01Ol2b`05
o`00obL01ol00bOo00020003olko00Ko00G>o`00o`02k@Ko00?]o`0090000olWo`06o`039ol00080
00?oc_l01_l01Lko003o00;]1_l00ngo000W0003obOo00Go00<Wo`000`000oo>o`05o`03c_l00080
00?o3ol01Ol00`oo000E0003oeco00Go0U`01Ol00?lW00Oo00<Wo`000P000ooNo`06o`05g_l00?l0
0Pl6o`033ol000@0000300;o00H0o`00o`03o`800_l20004o`3o00?o0`03o`040?l0o`800_l200?o
00H0o`00o`02obD00_l20004o`3o00?o0`03o`040?l0o`800_l200?o00H0o`00o`02obP00_l01P3o
003o00;o1002o`060?l00?l00_l300;o00H0o`00o`02oaH00_l01P3o003o00?o0P02o`8000Co0?l0
0ol300?o00@0o`3o0P02o`800ol01P3o003o00;o1@0000<000?o0?l010001?l00?l20004o`00o`<0
00Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0o`0U0004o`00o`<000Co003o0`001?l0
0?l30004o`00o`8000Co003o10000ol0o`0X0004o`00o`<000?o0?l010000ol0o`030004o`00o`<0
00?o0?l010000ol0o`0F0003o`3o00@000Co003o0P001?l00?l30004o`00o`<000Co003o0`001?l0
0?l20004o`00o`@000?o0?l01@000?l07@0001001_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o
6004o`030?l000Co0P06o`030?oo00;o4006o`800olK00Go0P03oa401Ol00`3oo`02o`<01?l00`3o
0003oaH01?l00`3o0004o`801_l00`3oo`02o`<01_l00`3oo`02o`801_l200?o1@00010000Oo;2`/
obco00</00Go0000o`03F`03oe_o00=K00Co003o18/3o`:;00?o00005P001?l?3`l3o`<?00Co003o
0b`00ol/o`03;003o`0000h000?oZJT00ZT3o`:Y00?o00006@001?l?3`l3o`8?00?o00003`001?o/
k>`3o`;/00Go0000o`033`?o0Pl00ol0000D0004o`l?3`?o0`l01?l00?l33`03o`oo00<?00Go0000
o`037@03oago00<M00Co003o1<h3o`;>00?o00000`00010000?o;2`01b`01Ol0003o00UK00Co003o
2H/00ol0000F0003o`l?00L?00Co003o2B`00ol0000>0003ojVY00NY00?o00006@000ol?3`063`03
o`0000l000?ok>`01^`01Ol0003o00P?00?o000050000ol?3`073`04o`00o`T?00Go0000o`097@04
o`00o`W>00?o00000`00010000?o;2`01b`01Ol0003o00UK00Co003o2H/00ol0000F0003o`l?00L?
00Co003o2B`00ol0000>0003ojVY00NY00?o00006@000ol?3`063`03o`0000l000?ok>`01^`01Ol0
003o00P?00?o000050000ol?3`073`04o`00o`T?00Go0000o`097@04o`00o`W>00?o00000`000100
00Oo;2`/obco00</00Go0000o`03F`03oe_o00=K00Co003o0h/4o`:;00?o00005P000ol?3`04o`<?
00Co003o0b`00ol/o`03;003o`0000h000CoZJVY1?l2Z@03o`0001T000?o3`l01?l23`03o`0000l0
00?ok>`01?l2k005o`000?l00Pl4o`8?00?o000050000ol?3`04o`<?00Co003o0`l00ol?o`033`05
o`000?l00ad00olMo`037@04o`00o`?>1?l2cP03o`0000<0000@00_o0`0;o`802olH00_o0P0;oa00
2olK00[o4@0:o`<02_lF00_o0P0;o`<02ol200_o1@00010000Co003o0`001?l00?l30004o`00o`<0
00Co003o0P001?l00?l40003o`3o01P000?o0?l010001?l00?l20004o`00o`<000Co003o40001?l0
0?l40003o`3o01/000?o0?l010000ol0o`0A0003o`3o00<000Co003o0`000ol0o`040003o`3o01H0
00?o0?l010001?l00?l20004o`00o`<000Co003o0`001?l00?l30004o`00o`8000Co003o10000ol0
o`050000o`0M0000o`0M0000o`0M0000o`0M0000o`0M0000o`0M0000o`0M0000\
\>"]],

Cell["\<\
Butterflies adapting their wing colouring to a bright background.\
\
\>", "NumberedFigure"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["External Notebooks \[Ellipsis]"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "All the necessary programs for the butterfly evolution examples can be \
found in the notebook ",
  ButtonBox["Butterflies.nb",
    ButtonData:>{"Butterflies.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(SetDirectory["\<...\>"]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<Butterflies.m\>"\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["References \[Ellipsis]"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Download the ",
  ButtonBox["latest version",
    ButtonData:>{
      URL[ 
      "http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html#\
Mimesis"], None},
    ButtonStyle->"Hyperlink"],
  " of this notebook from"
}], "Text"],

Cell["\<\
http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html\
\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowSize->{632, 638},
WindowMargins->{{Automatic, 119}, {Automatic, 52}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Butterfly Mimicry"}]]}, {Cell[ 
        TextData[ {"Butterfly Mimicry"}]], Inherited, Inherited}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
StyleDefinitions -> "../../StyleSheets/CourseStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 34, 0, 113, "Title"],
Cell[1768, 53, 108, 2, 62, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1901, 59, 31, 0, 61, "Section"],
Cell[1935, 61, 660, 14, 160, "Text"],
Cell[2598, 77, 433, 7, 122, "Text"],
Cell[3034, 86, 1028, 22, 217, "Text"],
Cell[4065, 110, 129, 3, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4231, 118, 47, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[4303, 122, 34, 0, 44, "Subsection"],
Cell[4340, 124, 1090, 38, 122, "Text"],
Cell[5433, 164, 335, 10, 65, "Text"],
Cell[5771, 176, 181, 8, 33, "Text"],
Cell[5955, 186, 155, 3, 46, "Text"],
Cell[6113, 191, 545, 15, 109, "Text"],

Cell[CellGroupData[{
Cell[6683, 210, 34, 0, 32, "Subsubsection"],
Cell[6720, 212, 263, 7, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7020, 224, 30, 0, 32, "Subsubsection"],
Cell[7053, 226, 537, 11, 122, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7639, 243, 65, 0, 30, "Subsection"],
Cell[7707, 245, 222, 6, 24, "Text"],
Cell[7932, 253, 182, 4, 40, "Text"],
Cell[8117, 259, 1358431, 24297, 507, 1266410, 23156, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1366551, 24558, 101, 3, 47, "NumberedFigure"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1366701, 24567, 139, 3, 45, "Section"],
Cell[1366843, 24572, 237, 7, 46, "Text"],
Cell[1367083, 24581, 110, 3, 47, "Input",
  InitializationCell->True],
Cell[1367196, 24586, 109, 3, 47, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1367342, 24594, 99, 2, 45, "Section"],
Cell[1367444, 24598, 259, 9, 24, "Text"],
Cell[1367706, 24609, 93, 3, 24, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

